<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Olympus
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! function_exists( 'olympus_body_classes' ) ) {
	/**
	 * Adds custom classes to the array of body classes.
	 *
	 * @param array $classes Classes for the body element.
	 * @return array
	 *
	 * @since 1.0.0
	 */
	function olympus_body_classes( $classes ) {
		$layout = olympus_get_layout();

		// Value have default, but we like to be extra careful.
		$classes[] = ( $layout ) ? $layout : 'no-sidebar';

		// Adds a class of hfeed to non-singular pages.
		if ( ! is_singular() ) {
			$classes[] = 'hfeed';
		}

		// Adds a class of no-sidebar when there is no sidebar present.
		if ( ! is_active_sidebar( 'olympus-sidebar' ) ) {
			$classes[] = 'no-sidebar';
		}

		return $classes;
	}
	add_filter( 'body_class', 'olympus_body_classes' );
}

if ( ! function_exists( 'olympus_pingback_header' ) ) {
	/**
	 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
	 *
	 * @since 1.0.0
	 */
	function olympus_pingback_header() {
		if ( is_singular() && pings_open() ) {
			printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
		}
	}
	add_action( 'wp_head', 'olympus_pingback_header' );
}

if ( ! function_exists( 'olympus_get_media_query' ) ) {
	/**
	 * Get our media queries.
	 *
	 * @param string $name Name of the media query.
	 * @return string The full media query.
	 *
	 * @since 1.0.0
	 */
	function olympus_get_media_query( $name ) {
		$desktop = apply_filters( 'olympus_desktop_media_query', '(min-width:1025px)' );
		$tablet = apply_filters( 'olympus_tablet_media_query', '(min-width: 769px) and (max-width: 1024px)' );
		$mobile = apply_filters( 'olympus_mobile_media_query', '(max-width:768px)' );
		$mobile_menu = apply_filters( 'olympus_mobile_menu_media_query', $mobile );

		$queries = apply_filters(
			'olympus_media_queries',
			array(
				'desktop' => $desktop,
				'tablet' => $tablet,
				'mobile' => $mobile,
				'mobile-menu' => $mobile_menu,
			)
		);

		return $queries[ $name ];
	}
}

if ( ! function_exists( 'olympus_get_microdata' ) ) {
	/**
	 * Get any necessary microdata.
	 *
	 * @param string $context The element to target.
	 * @return string Our final attribute to add to the element.
	 *
	 * @since 1.0.0
	 */
	function olympus_get_microdata( $context ) {
		$data = false;

		if ( 'body' === $context ) {
			$type = 'WebPage';

			if ( is_home() || is_archive() || is_attachment() || is_tax() || is_single() ) {
				$type = 'Blog';
			}

			if ( is_search() ) {
				$type = 'SearchResultsPage';
			}

			$type = apply_filters( 'olympus_body_itemtype', $type );

			$data = sprintf(
				'itemtype="https://schema.org/%s" itemscope',
				esc_html( $type )
			);
		}

		if ( 'header' === $context ) {
			$data = 'itemtype="https://schema.org/WPHeader" itemscope';
		}

		if ( 'navigation' === $context ) {
			$data = 'itemtype="https://schema.org/SiteNavigationElement" itemscope';
		}

		if ( 'article' === $context ) {
			$type = apply_filters( 'olympus_article_itemtype', 'CreativeWork' );

			$data = sprintf(
				'itemtype="https://schema.org/%s" itemscope',
				esc_html( $type )
			);
		}

		if ( 'headline' === $context ) {
			$data = 'itemprop="headline"';
		}

		if ( 'description' === $context ) {
			$data = 'itemprop="description"';
		}

		if ( 'name' === $context ) {
			$data = 'itemprop="name"';
		}

		if ( 'url' === $context ) {
			$data = 'itemprop="url"';
		}

		if ( 'text' === $context ) {
			$data = 'itemprop="text"';
		}

		if ( 'post-author' === $context ) {
			$data = 'itemprop="author" itemtype="https://schema.org/Person" itemscope';
		}

		if ( 'comment-body' === $context ) {
			$data = 'itemtype="https://schema.org/Comment" itemscope';
		}

		if ( 'comment-author' === $context ) {
			$data = 'itemprop="author" itemtype="https://schema.org/Person" itemscope';
		}

		if ( 'sidebar' === $context ) {
			$data = 'itemtype="https://schema.org/WPSideBar" itemscope';
		}

		if ( 'footer' === $context ) {
			$data = 'itemtype="https://schema.org/WPFooter" itemscope';
		}

		if ( $data ) {
			return apply_filters( "olympus_{$context}_microdata", $data );
		}
	}
}

if ( ! function_exists( 'olympus_do_microdata' ) ) {
	/**
	 * Output our microdata for an element.
	 *
	 * @param string $context The element to target.
	 *
	 * @since 1.0.0
	 */
	function olympus_do_microdata( $context ) {
		echo olympus_get_microdata( $context ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped -- Escaped in function.
	}
}

if ( ! function_exists( 'olympus_get_svg_icon' ) ) {
	/**
	 * Create SVG icons.
	 *
	 * @param string $icon The icon to get.
	 *
	 * @since 1.0.0
	 */
	function olympus_get_svg_icon( $icon ) {
		$output = '';

		if ( 'menu-bars' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 512 512"><path d="M0 96c0-13.255 10.745-24 24-24h464c13.255 0 24 10.745 24 24s-10.745 24-24 24H24c-13.255 0-24-10.745-24-24zm0 160c0-13.255 10.745-24 24-24h464c13.255 0 24 10.745 24 24s-10.745 24-24 24H24c-13.255 0-24-10.745-24-24zm0 160c0-13.255 10.745-24 24-24h464c13.255 0 24 10.745 24 24s-10.745 24-24 24H24c-13.255 0-24-10.745-24-24z"></path></svg><svg viewBox="0 0 512 512" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><path d="M71.029 71.029c9.373-9.372 24.569-9.372 33.942 0L256 222.059l151.029-151.03c9.373-9.372 24.569-9.372 33.942 0 9.372 9.373 9.372 24.569 0 33.942L289.941 256l151.03 151.029c9.372 9.373 9.372 24.569 0 33.942-9.373 9.372-24.569 9.372-33.942 0L256 289.941l-151.029 151.03c-9.373 9.372-24.569 9.372-33.942 0-9.372-9.373-9.372-24.569 0-33.942L222.059 256 71.029 104.971c-9.372-9.373-9.372-24.569 0-33.942z"></path></svg>';
		}

		if ( 'close' === $icon ) {
			$output = '<svg viewBox="0 0 512 512" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><path d="M71.029 71.029c9.373-9.372 24.569-9.372 33.942 0L256 222.059l151.029-151.03c9.373-9.372 24.569-9.372 33.942 0 9.372 9.373 9.372 24.569 0 33.942L289.941 256l151.03 151.029c9.372 9.373 9.372 24.569 0 33.942-9.373 9.372-24.569 9.372-33.942 0L256 289.941l-151.029 151.03c-9.373 9.372-24.569 9.372-33.942 0-9.372-9.373-9.372-24.569 0-33.942L222.059 256 71.029 104.971c-9.372-9.373-9.372-24.569 0-33.942z"></path></svg>';
		}

		if ( 'arrow-up' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 611.986 512"><path d="M596.145,405.201L347.627,129.608c-11.418-11.494-26.691-16.551-41.633-15.631c-14.967-0.945-30.215,4.112-41.633,15.631 L15.842,405.201c-21.123,21.251-21.123,55.731,0,76.982c21.123,21.25,55.399,21.25,76.522,0l213.629-236.898l213.629,236.898 c21.123,21.25,55.398,21.25,76.521,0C617.268,460.933,617.268,426.452,596.145,405.201z"/></svg>';
		}

		if ( 'arrow-left' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 512 792.082"><path d="M317.896,396.024l304.749-276.467c27.36-27.36,27.36-71.677,0-99.037s-71.677-27.36-99.036,0L169.11,342.161 c-14.783,14.783-21.302,34.538-20.084,53.897c-1.218,19.359,5.301,39.114,20.084,53.897l354.531,321.606 c27.36,27.36,71.677,27.36,99.037,0s27.36-71.677,0-99.036L317.896,396.024z"/></svg>';
		}

		if ( 'arrow-down' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 612.007 512"><path d="M596.168,130.647c-21.119-21.169-55.382-21.169-76.526,0L306.013,366.44L92.384,130.647 c-21.144-21.169-55.382-21.169-76.525,0c-21.144,21.169-21.144,55.458,0,76.627l248.504,274.31 c11.438,11.438,26.672,16.482,41.651,15.54c14.953,0.942,30.213-4.102,41.65-15.54l248.505-274.31 C617.287,186.105,617.287,151.817,596.168,130.647z"/></svg>';
		}

		if ( 'arrow-right' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 512 792.049"><path d="M622.955,342.127L268.424,20.521c-27.36-27.36-71.677-27.36-99.037,0c-27.36,27.36-27.36,71.676,0,99.037 l304.749,276.468L169.387,672.492c-27.36,27.359-27.36,71.676,0,99.036s71.677,27.36,99.037,0l354.531-321.606 c14.783-14.783,21.302-34.538,20.084-53.897C644.225,376.665,637.738,356.911,622.955,342.127z"/></svg>';
		}

		if ( 'nav-left-arrow' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 386.242 386.242"><path d="M374.212,182.3H39.432l100.152-99.767c4.704-4.704,4.704-12.319,0-17.011 c-4.704-4.704-12.319-4.704-17.011,0L3.474,184.61c-4.632,4.632-4.632,12.379,0,17.011l119.1,119.1 c4.704,4.704,12.319,4.704,17.011,0c4.704-4.704,4.704-12.319,0-17.011L39.432,206.36h334.779c6.641,0,12.03-5.39,12.03-12.03 S380.852,182.3,374.212,182.3z"/></svg>';
		}

		if ( 'nav-right-arrow' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 384.97 384.97"><path d="M384.97,192.487c0-3.212-1.323-6.28-3.525-8.59L262.357,63.606c-4.704-4.752-12.319-4.74-17.011,0 c-4.704,4.74-4.704,12.439,0,17.179l98.564,99.551H12.03C5.39,180.337,0,185.774,0,192.487c0,6.713,5.39,12.151,12.03,12.151 h331.868l-98.552,99.551c-4.704,4.74-4.692,12.439,0,17.179c4.704,4.74,12.319,4.74,17.011,0l119.088-120.291 C383.694,198.803,384.934,195.675,384.97,192.487z"/></svg>';
		}

		if ( 'scroll-up' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 240.835 240.835"><path d="M129.007,57.819c-4.68-4.68-12.499-4.68-17.191,0L3.555,165.803c-4.74,4.74-4.74,12.427,0,17.155 c4.74,4.74,12.439,4.74,17.179,0l99.683-99.406l99.671,99.418c4.752,4.74,12.439,4.74,17.191,0c4.74-4.74,4.74-12.427,0-17.155 L129.007,57.819z"/></svg>';
		}

		if ( 'meta-author' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 428.974 428.975"><path d="M414.101,373.866l-106.246-56.188l-4.907-15.332c-1.469-5.137-3.794-10.273-8.576-11.623 c-1.519-0.428-3.441-3.201-3.689-5.137l-2.836-29.813c-0.156-2.553,0.868-4.844,2.216-6.453 c8.14-9.754,12.577-21.051,14.454-33.967c0.944-6.494,4.323-12.483,6.059-18.879l6.812-35.649 c0.711-4.681,0.573-8.289-4.659-10.103c-1.443-0.503-2.699-2.894-2.699-6.479l0.069-67.264 c-1.111-16.28-9.731-28.869-21.957-37.631c-23.354-16.739-65.175-8.977-51.526-36.281c0.806-1.607,0.549-4.399-5.062-2.335 c-20.936,7.703-76.701,28.057-90.71,38.616c-12.538,9.449-20.844,21.351-21.957,37.631l0.069,67.264c0,2.96-1.255,5.976-2.7,6.479 c-5.233,1.813-5.37,5.422-4.659,10.103l6.814,35.649c1.732,6.396,5.113,12.386,6.058,18.879 c1.875,12.916,6.315,24.213,14.453,33.967c1.347,1.609,2.372,3.9,2.216,6.453l-2.836,29.813c-0.249,1.936-2.174,4.709-3.69,5.137 c-4.783,1.35-7.109,6.486-8.577,11.623l-4.909,15.332l-106.25,56.188c-2.742,1.449-4.457,4.297-4.457,7.397v39.343 c0,4.621,3.748,8.368,8.37,8.368h391.4c4.622,0,8.37-3.747,8.37-8.368v-39.343C418.557,378.163,416.842,375.315,414.101,373.866z"/></svg>';
		}

		if ( 'meta-date' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 512 512"><path d="M256,239c-9.374,0-17,7.626-17,17c0,9.374,7.626,17,17,17c9.374,0,17-7.626,17-17C273,246.626,265.374,239,256,239z"/><path d="M437.02,74.981C388.667,26.629,324.38,0,256,0S123.333,26.629,74.981,74.98C26.629,123.333,0,187.62,0,256 s26.629,132.667,74.98,181.019C123.333,485.371,187.62,512,256,512s132.667-26.629,181.019-74.98 C485.371,388.667,512,324.38,512,256S485.371,123.333,437.02,74.981z M48,271h-2c-8.284,0-15-6.716-15-15s6.716-15,15-15h2 c8.284,0,15,6.716,15,15S56.284,271,48,271z M241,46c0-8.284,6.716-15,15-15s15,6.716,15,15v2c0,8.284-6.716,15-15,15 s-15-6.716-15-15V46z M119.528,413.685l-1.414,1.415c-5.858,5.858-15.355,5.858-21.213,0c-5.858-5.858-5.858-15.355,0-21.213 l1.414-1.414c5.858-5.858,15.355-5.858,21.213,0C125.386,398.331,125.386,407.827,119.528,413.685z M119.528,119.528 c-5.858,5.858-15.355,5.858-21.213,0l-1.414-1.414c-5.858-5.858-5.858-15.355,0-21.213c5.858-5.858,15.355-5.858,21.213,0 l1.414,1.415C125.386,104.173,125.386,113.67,119.528,119.528z M271,466c0,8.284-6.716,15-15,15s-15-6.716-15-15v-2 c0-8.284,6.716-15,15-15s15,6.716,15,15V466z M368,271h-67.469c-6.276,18.58-23.86,32-44.531,32c-25.916,0-47-21.084-47-47 c0-20.671,13.42-38.255,32-44.531V112c0-8.284,6.716-15,15-15s15,6.716,15,15v99.469c13.866,4.684,24.848,15.665,29.531,29.531 H368c8.284,0,15,6.716,15,15S376.284,271,368,271z M415.099,415.099c-5.858,5.858-15.355,5.858-21.213,0l-1.414-1.415 c-5.858-5.857-5.858-15.355,0-21.213c5.858-5.858,15.355-5.858,21.213,0l1.414,1.414 C420.957,399.744,420.957,409.241,415.099,415.099z M415.099,118.114l-1.414,1.414c-5.858,5.858-15.355,5.858-21.213,0 c-5.858-5.858-5.858-15.355,0-21.213l1.414-1.415c5.858-5.858,15.355-5.858,21.213,0 C420.957,102.758,420.957,112.256,415.099,118.114z M466,271h-2c-8.284,0-15-6.716-15-15s6.716-15,15-15h2c8.284,0,15,6.716,15,15 S474.284,271,466,271z"/></svg>';
		}

		if ( 'meta-cat' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 512 512"><path d="M403.626,85.731H139.537c-8.181,0-14.813-6.632-14.813-14.813v-7.412c0-8.341-6.762-15.103-15.103-15.103H30.206 C13.524,48.403,0,61.926,0,78.609v254.163l38.757-188.557c1.416-6.888,7.478-11.831,14.51-11.831h380.565v-16.447 C433.832,99.254,420.308,85.731,403.626,85.731z"/><path d="M481.79,162.01H65.345v0L7.058,445.577c-1.912,9.304,5.194,18.02,14.693,18.02h433.357 c15.397,0,28.33-11.581,30.023-26.885l26.682-241.174C513.792,177.649,499.787,162.01,481.79,162.01z"/></svg>';
		}

		if ( 'meta-comments' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 511.999 511.999"><path d="M113.304,396.177c-41.405-40.668-66.722-93.368-72.6-150.216c-22.006,27.818-33.938,61.937-33.883,97.745 c0.037,23.29,5.279,46.441,15.212,67.376L1.551,470.689c-3.521,10.247-0.949,21.373,6.713,29.036 c5.392,5.392,12.501,8.264,19.812,8.264c3.076,0,6.188-0.508,9.223-1.551l59.609-20.483c20.935,9.933,44.086,15.175,67.376,15.212 c36.509,0.049,71.256-12.338,99.361-35.168C207.133,460.886,154.416,436.556,113.304,396.177z"/><path d="M510.156,401.842L480.419,315.3c14.334-29.302,21.909-61.89,21.96-94.679c0.088-57.013-21.97-110.92-62.112-151.79 C400.117,27.952,346.615,4.942,289.615,4.039C230.51,3.104,174.954,25.586,133.187,67.352 C91.42,109.119,68.934,164.674,69.87,223.782c0.903,56.999,23.913,110.502,64.79,150.652 c40.79,40.064,94.56,62.116,151.451,62.114c0.112,0,0.23,0,0.34,0c32.79-0.051,65.378-7.626,94.68-21.96l86.544,29.738 c3.606,1.239,7.304,1.843,10.959,1.843c8.688,0,17.136-3.412,23.545-9.822C511.284,427.241,514.34,414.021,510.156,401.842z M307.004,295.328H195.331c-8.416,0-15.238-6.823-15.238-15.238c0-8.416,6.823-15.238,15.238-15.238h111.672 c8.416,0,15.238,6.823,15.238,15.238C322.241,288.506,315.42,295.328,307.004,295.328z M376.892,232.659h-181.56 c-8.416,0-15.238-6.823-15.238-15.238s6.823-15.238,15.238-15.238h181.56c8.416,0,15.238,6.823,15.238,15.238 S385.308,232.659,376.892,232.659z M376.892,169.988h-181.56c-8.416,0-15.238-6.823-15.238-15.238 c0-8.416,6.823-15.238,15.238-15.238h181.56c8.416,0,15.238,6.823,15.238,15.238C392.13,163.165,385.308,169.988,376.892,169.988z"/></svg>';
		}

		if ( 'tags' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 512 512"><path d="M444.07,67.946H302.344c-13.613,0-26.409,5.301-36.034,14.927L65.872,283.312c-9.626,9.625-14.927,22.422-14.927,36.034 s5.301,26.409,14.927,36.034L207.596,497.1c9.934,9.934,22.984,14.9,36.033,14.9s26.099-4.967,36.033-14.902l200.44-200.44 c9.626-9.626,14.927-22.422,14.927-36.034v-141.72C495.029,90.806,472.169,67.946,444.07,67.946z M376.124,237.81 c-28.099,0-50.959-22.86-50.959-50.959s22.86-50.959,50.959-50.959s50.959,22.86,50.959,50.959S404.223,237.81,376.124,237.81z"/><path d="M410.097,0H268.371c-13.613,0-26.409,5.301-36.034,14.927L31.899,215.366c-9.626,9.625-14.927,22.422-14.927,36.034 c0,10.647,3.256,20.788,9.276,29.31c3.999-7.81,9.219-15.04,15.603-21.422L242.288,58.849 c16.041-16.041,37.369-24.876,60.056-24.876h141.724c4.942,0,9.78,0.448,14.493,1.263C451.918,14.81,432.709,0,410.097,0z"/></svg>';
		}

		if ( 'error' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:svgjs="http://svgjs.com/svgjs" version="1.1" width="512" height="512" x="0" y="0" viewBox="0 0 512 512" xml:space="preserve"><path d="M84.446,317.403H13.082C5.649,317.403,0,312.348,0,303.724c0-2.378,39.246-146.295,39.246-146.295 c3.568-7.434,10.11-10.11,16.354-10.11c6.839,0,23.99,4.614,23.99,13.536c0,1.487,0.073,4.603-0.82,6.386L49.655,281.423h34.791 v-31.221c0-8.622,9.812-12.191,19.327-12.191c9.814,0,19.328,3.568,19.328,12.191v31.221h13.975 c8.029,0,12.192,8.921,12.192,18.138c0,8.92-5.949,17.842-12.192,17.842h-13.975v35.087c0,8.029-9.515,12.191-19.328,12.191 c-9.515,0-19.327-4.163-19.327-12.191V317.403z" fill="#e5bf63"/><path d="M390.515,199.571c6.446-23.746,11.462-42.142,11.462-42.142c3.568-7.434,10.11-10.11,16.354-10.11 c6.839,0,23.99,4.614,23.99,13.536c0,1.487,0.073,4.603-0.82,6.386l-29.114,114.182h34.791v-31.221 c0-8.622,9.812-12.191,19.327-12.191c9.814,0,19.328,3.568,19.328,12.191v31.221h13.975c8.029,0,12.192,8.921,12.192,18.138 c0,8.92-5.949,17.842-12.192,17.842h-13.975v35.087c0,8.029-9.515,12.191-19.328,12.191c-9.515,0-19.327-4.163-19.327-12.191 v-35.087h-71.365c-7.433,0-13.082-5.055-13.082-13.679c0-1.191,9.84-37.869,19.666-74.197L390.515,199.571z" fill="#e5bf63"/><circle cx="256.009" cy="263.073" r="88.481" fill="#f9572b"/><path d="M267.088,263.076l30.777-30.777c3.06-3.06,3.06-8.023,0-11.082c-3.062-3.06-8.023-3.06-11.083,0 l-30.777,30.777l-30.777-30.777c-3.062-3.06-8.023-3.06-11.083,0c-3.06,3.06-3.06,8.023,0,11.082l30.777,30.777l-30.777,30.777  c-3.06,3.06-3.06,8.023,0,11.082c1.531,1.53,3.537,2.296,5.542,2.296s4.011-0.765,5.542-2.296l30.777-30.777l30.777,30.777  c1.531,1.53,3.537,2.296,5.542,2.296s4.011-0.765,5.542-2.296c3.06-3.06,3.06-8.023,0-11.082L267.088,263.076z" fill="#ffffff"/></svg>';
		}

		if ( 'full-width' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 50 40" width="40" height="50"><path class="fw-in" fill="#fff" d="M49.007 2.918a1.9 1.9 0 00-1.898-1.898H2.891A1.9 1.9 0 00.993 2.918v34.164a1.9 1.9 0 001.898 1.898h44.218a1.9 1.9 0 001.898-1.898V2.918z"></path><path class="in" fill="#ddd" d="M1.19 1.153H48.809999999999995V12.969000000000001H1.19z"></path><path class="in" fill="#ddd" fill-rule="nonzero" d="M37.149 34.831H2.714c-.411 0-.749.433-.749.959s.338.959.749.959h44.435c.411 0 .749-.433.749-.959s-.338-.959-.749-.959zM47.038 30.979H2.924a.964.964 0 00-.959.959c0 .527.433.959.959.959h44.114a.963.963 0 00.959-.959.964.964 0 00-.959-.959z"></path><path class="in" fill="#ddd" fill-rule="nonzero" d="M47.038 27.128H2.924a.964.964 0 00-.959.959c0 .526.433.959.959.959h44.114a.964.964 0 00.959-.959.964.964 0 00-.959-.959zM47.038 23.277H2.924a.964.964 0 00-.959.959c0 .526.433.959.959.959h44.114a.964.964 0 00.959-.959.964.964 0 00-.959-.959z"></path><path class="in" fill="#ddd" fill-rule="nonzero" d="M47.038 19.426H2.924a.964.964 0 00-.959.959c0 .526.433.959.959.959h44.114a.964.964 0 00.959-.959.964.964 0 00-.959-.959zM47.038 15.575H2.924a.964.964 0 00-.959.959c0 .526.433.959.959.959h44.114a.964.964 0 00.959-.959.964.964 0 00-.959-.959z"></path><path class="fw-out" fill="none" stroke="#ddd" stroke-width="1" d="M49.007 2.918a1.9 1.9 0 00-1.898-1.898H2.891A1.9 1.9 0 00.993 2.918v34.164a1.9 1.9 0 001.898 1.898h44.218a1.9 1.9 0 001.898-1.898V2.918z"></path></svg>';
		}

		if ( 'left-sidebar' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 50 40" width="40" height="50"><path class="out" fill="#fff" stroke="#ddd" stroke-width="1" d="M49.007 2.918a1.9 1.9 0 00-1.898-1.898H2.891A1.9 1.9 0 00.993 2.918v34.164a1.9 1.9 0 001.898 1.898h44.218a1.9 1.9 0 001.898-1.898V2.918z"></path><path class="in" fill="#ddd" d="M19.784 3.855H42.483999999999995V13.857000000000001H19.784z"></path><g fill-rule="nonzero"><path class="in" fill="#ddd" d="M37.131 34.421H20.145c-.203 0-.37.409-.37.907 0 .498.167.907.37.907h21.986c.202 0 .369-.409.369-.907 0-.498-.167-.907-.369-.907zM42.02 30.777H20.26c-.26 0-.473.41-.473.908 0 .497.213.907.473.907h21.76c.26 0 .473-.41.473-.907 0-.498-.213-.908-.473-.908z"></path><path class="in" fill="#ddd" d="M42.02 27.134H20.26c-.26 0-.473.41-.473.907 0 .498.213.907.473.907h21.76c.26 0 .473-.409.473-.907 0-.497-.213-.907-.473-.907zM42.02 23.491H20.26c-.26 0-.473.409-.473.907 0 .498.213.907.473.907h21.76c.26 0 .473-.409.473-.907 0-.498-.213-.907-.473-.907z"></path><path class="in" fill="#ddd" d="M42.02 19.847H20.26c-.26 0-.473.41-.473.907 0 .498.213.908.473.908h21.76c.26 0 .473-.41.473-.908 0-.497-.213-.907-.473-.907zM42.02 16.204H20.26c-.26 0-.473.409-.473.907 0 .498.213.907.473.907h21.76c.26 0 .473-.409.473-.907 0-.498-.213-.907-.473-.907z"></path></g><path class="in" fill="#ddd" d="M7.507 3.892H17.398V36.143H7.507z"></path></svg>';
		}

		if ( 'right-sidebar' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 50 40" width="40" height="50"><path class="out" fill="#fff" stroke="#ddd" stroke-width="1" d="M49.007 2.918a1.9 1.9 0 00-1.898-1.898H2.891A1.9 1.9 0 00.993 2.918v34.164a1.9 1.9 0 001.898 1.898h44.218a1.9 1.9 0 001.898-1.898V2.918z"></path><path class="in" fill="#ddd" d="M7.516 3.855H30.216V13.857000000000001H7.516z"></path><g fill-rule="nonzero"><path class="in" fill="#ddd" d="M7.874 34.421h21.987c.202 0 .369.409.369.907 0 .498-.167.907-.369.907H7.874c-.202 0-.369-.409-.369-.907 0-.498.167-.907.369-.907zM7.98 30.777h21.76c.26 0 .473.41.473.908 0 .497-.213.907-.473.907H7.98c-.26 0-.473-.41-.473-.907 0-.498.213-.908.473-.908z"></path><path class="in" fill="#ddd" d="M7.98 27.134h21.76c.26 0 .473.41.473.907 0 .498-.213.907-.473.907H7.98c-.26 0-.473-.409-.473-.907 0-.497.213-.907.473-.907zM7.98 23.491h21.76c.26 0 .473.409.473.907 0 .498-.213.907-.473.907H7.98c-.26 0-.473-.409-.473-.907 0-.498.213-.907.473-.907z"></path><path class="in" fill="#ddd" d="M7.98 19.847h21.76c.26 0 .473.41.473.907 0 .498-.213.908-.473.908H7.98c-.26 0-.473-.41-.473-.908 0-.497.213-.907.473-.907zM7.98 16.204h21.76c.26 0 .473.409.473.907 0 .498-.213.907-.473.907H7.98c-.26 0-.473-.409-.473-.907 0-.498.213-.907.473-.907z"></path></g><path class="in" fill="#ddd" d="M32.602 3.892H42.492999999999995V36.143H32.602z"></path></svg>';
		}

		if ( 'no-sidebar' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 50 40" width="40" height="50"><path class="out" fill="#fff" stroke="#ddd" stroke-width="1" d="M49.007 2.918a1.9 1.9 0 00-1.898-1.898H2.891A1.9 1.9 0 00.993 2.918v34.164a1.9 1.9 0 001.898 1.898h44.218a1.9 1.9 0 001.898-1.898V2.918z"></path><path class="in" fill="#ddd" d="M12.511 3.877H37.497V13.879000000000001H12.511z"></path><path class="in" fill="#ddd" fill-rule="nonzero" d="M31.588 34.498H12.91c-.223 0-.407.41-.407.908 0 .497.184.907.407.907h23.678c.224 0 .407-.41.407-.907 0-.498-.183-.908-.407-.908zM36.965 30.855H13.036c-.285 0-.52.409-.52.907 0 .498.235.907.52.907h23.929c.285 0 .52-.409.52-.907 0-.498-.235-.907-.52-.907z"></path><path class="in" fill="#ddd" fill-rule="nonzero" d="M36.965 27.211H13.036c-.285 0-.52.41-.52.908 0 .497.235.907.52.907h23.929c.285 0 .52-.41.52-.907 0-.498-.235-.908-.52-.908zM36.965 23.568H13.036c-.285 0-.52.41-.52.907 0 .498.235.908.52.908h23.929c.285 0 .52-.41.52-.908 0-.497-.235-.907-.52-.907z"></path><path class="in" fill="#ddd" fill-rule="nonzero" d="M36.965 19.925H13.036c-.285 0-.52.409-.52.907 0 .498.235.907.52.907h23.929c.285 0 .52-.409.52-.907 0-.498-.235-.907-.52-.907zM36.965 16.281H13.036c-.285 0-.52.41-.52.907 0 .498.235.908.52.908h23.929c.285 0 .52-.41.52-.908 0-.497-.235-.907-.52-.907z"></path></svg>';
		}

		if ( 'align-left' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 448 512"><path d="M12.83 352h262.34A12.82 12.82 0 0 0 288 339.17v-38.34A12.82 12.82 0 0 0 275.17 288H12.83A12.82 12.82 0 0 0 0 300.83v38.34A12.82 12.82 0 0 0 12.83 352zm0-256h262.34A12.82 12.82 0 0 0 288 83.17V44.83A12.82 12.82 0 0 0 275.17 32H12.83A12.82 12.82 0 0 0 0 44.83v38.34A12.82 12.82 0 0 0 12.83 96zM432 160H16a16 16 0 0 0-16 16v32a16 16 0 0 0 16 16h416a16 16 0 0 0 16-16v-32a16 16 0 0 0-16-16zm0 256H16a16 16 0 0 0-16 16v32a16 16 0 0 0 16 16h416a16 16 0 0 0 16-16v-32a16 16 0 0 0-16-16z"></path></svg>';
		}

		if ( 'align-center' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 448 512"><path d="M432 160H16a16 16 0 0 0-16 16v32a16 16 0 0 0 16 16h416a16 16 0 0 0 16-16v-32a16 16 0 0 0-16-16zm0 256H16a16 16 0 0 0-16 16v32a16 16 0 0 0 16 16h416a16 16 0 0 0 16-16v-32a16 16 0 0 0-16-16zM108.1 96h231.81A12.09 12.09 0 0 0 352 83.9V44.09A12.09 12.09 0 0 0 339.91 32H108.1A12.09 12.09 0 0 0 96 44.09V83.9A12.1 12.1 0 0 0 108.1 96zm231.81 256A12.09 12.09 0 0 0 352 339.9v-39.81A12.09 12.09 0 0 0 339.91 288H108.1A12.09 12.09 0 0 0 96 300.09v39.81a12.1 12.1 0 0 0 12.1 12.1z"></path></svg>';
		}

		if ( 'align-right' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 448 512"><path d="M16 224h416a16 16 0 0 0 16-16v-32a16 16 0 0 0-16-16H16a16 16 0 0 0-16 16v32a16 16 0 0 0 16 16zm416 192H16a16 16 0 0 0-16 16v32a16 16 0 0 0 16 16h416a16 16 0 0 0 16-16v-32a16 16 0 0 0-16-16zm3.17-384H172.83A12.82 12.82 0 0 0 160 44.83v38.34A12.82 12.82 0 0 0 172.83 96h262.34A12.82 12.82 0 0 0 448 83.17V44.83A12.82 12.82 0 0 0 435.17 32zm0 256H172.83A12.82 12.82 0 0 0 160 300.83v38.34A12.82 12.82 0 0 0 172.83 352h262.34A12.82 12.82 0 0 0 448 339.17v-38.34A12.82 12.82 0 0 0 435.17 288z"></path></svg>';
		}

		if ( 'search-icon' === $icon ) {
			$output = '<svg version="1.1" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512" xmlns:xlink="http://www.w3.org/1999/xlink" enable-background="new 0 0 512 512"><path d="M495,466.2L377.2,348.4c29.2-35.6,46.8-81.2,46.8-130.9C424,103.5,331.5,11,217.5,11C103.4,11,11,103.5,11,217.5 S103.4,424,217.5,424c49.7,0,95.2-17.5,130.8-46.7L466.1,495c8,8,20.9,8,28.9,0C503,487.1,503,474.1,495,466.2z M217.5,382.9 C126.2,382.9,52,308.7,52,217.5S126.2,52,217.5,52C308.7,52,383,126.3,383,217.5S308.7,382.9,217.5,382.9z"/></svg>';
		}

		if ( 'cart-icon' === $icon ) {
			$output = '<svg viewBox="0 0 511.728 511.728" xmlns="http://www.w3.org/2000/svg"><path d="m147.925 379.116c-22.357-1.142-21.936-32.588-.001-33.68 62.135.216 226.021.058 290.132.103 17.535 0 32.537-11.933 36.481-29.017l36.404-157.641c2.085-9.026-.019-18.368-5.771-25.629s-14.363-11.484-23.626-11.484c-25.791 0-244.716-.991-356.849-1.438l-17.775-65.953c-4.267-15.761-18.65-26.768-34.978-26.768h-56.942c-8.284 0-15 6.716-15 15s6.716 15 15 15h56.942c2.811 0 5.286 1.895 6.017 4.592l68.265 253.276c-12.003.436-23.183 5.318-31.661 13.92-8.908 9.04-13.692 21.006-13.471 33.695.442 25.377 21.451 46.023 46.833 46.023h21.872c-3.251 6.824-5.076 14.453-5.076 22.501 0 28.95 23.552 52.502 52.502 52.502s52.502-23.552 52.502-52.502c0-8.049-1.826-15.677-5.077-22.501h94.716c-3.248 6.822-5.073 14.447-5.073 22.493 0 28.95 23.553 52.502 52.502 52.502 28.95 0 52.503-23.553 52.503-52.502 0-8.359-1.974-16.263-5.464-23.285 5.936-1.999 10.216-7.598 10.216-14.207 0-8.284-6.716-15-15-15zm91.799 52.501c0 12.408-10.094 22.502-22.502 22.502s-22.502-10.094-22.502-22.502c0-12.401 10.084-22.491 22.483-22.501h.038c12.399.01 22.483 10.1 22.483 22.501zm167.07 22.494c-12.407 0-22.502-10.095-22.502-22.502 0-12.285 9.898-22.296 22.137-22.493h.731c12.24.197 22.138 10.208 22.138 22.493-.001 12.407-10.096 22.502-22.504 22.502zm74.86-302.233c.089.112.076.165.057.251l-15.339 66.425h-51.942l8.845-67.023 58.149.234c.089.002.142.002.23.113zm-154.645 163.66v-66.984h53.202l-8.84 66.984zm-74.382 0-8.912-66.984h53.294v66.984zm-69.053 0h-.047c-3.656-.001-6.877-2.467-7.828-5.98l-16.442-61.004h54.193l8.912 66.984zm56.149-96.983-9.021-67.799 66.306.267v67.532zm87.286 0v-67.411l66.022.266-8.861 67.145zm-126.588-67.922 9.037 67.921h-58.287l-18.38-68.194zm237.635 164.905h-36.426l8.84-66.984h48.973l-14.137 61.217c-.784 3.396-3.765 5.767-7.25 5.767z"/></svg>';
		}

		if ( 'website' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 511.999 511.999"><path d="M437.019,74.981C388.667,26.628,324.38,0,256,0C187.62,0,123.332,26.628,74.981,74.98C26.628,123.332,0,187.62,0,256 s26.628,132.667,74.981,181.019C123.332,485.371,187.62,511.999,256,511.999c68.381,0,132.667-26.628,181.02-74.981 c48.351-48.351,74.98-112.639,74.98-181.019S485.371,123.332,437.019,74.981z M96.216,96.216 c22.511-22.511,48.938-39.681,77.742-50.888c-7.672,9.578-14.851,20.587-21.43,32.969c-7.641,14.38-14.234,30.173-19.725,47.042 c-19.022-3.157-36.647-7.039-52.393-11.595C85.345,107.678,90.61,101.822,96.216,96.216z M62.229,139.585 c18.417,5.897,39.479,10.87,62.461,14.809c-6.4,27.166-10.167,56.399-11.066,86.591H30.536 C32.896,204.752,43.778,170.172,62.229,139.585z M60.594,369.638c-17.455-29.899-27.769-63.481-30.059-98.623h83.146 c0.982,29.329,4.674,57.731,10.858,84.186C101.085,359.003,79.494,363.85,60.594,369.638z M96.216,415.784 c-6.38-6.381-12.322-13.081-17.831-20.055c16.323-4.526,34.571-8.359,54.214-11.433c5.53,17.103,12.194,33.105,19.928,47.662 c7.17,13.493,15.053,25.349,23.51,35.505C146.427,456.28,119.268,438.834,96.216,415.784z M240.984,478.115 c-22.808-6.389-44.384-27.217-61.936-60.249c-6.139-11.552-11.531-24.155-16.15-37.587c24.73-2.722,51.045-4.331,78.086-4.709 V478.115z M240.984,345.537c-29.988,0.409-59.217,2.292-86.59,5.507c-6.038-24.961-9.671-51.978-10.668-80.028h97.259V345.537z M240.984,240.984h-97.315c0.911-28.834,4.602-56.605,10.828-82.201c27.198,3.4,56.366,5.468,86.487,6.06V240.984z M240.984,134.808c-27.146-0.547-53.403-2.317-77.958-5.205c4.591-13.292,9.941-25.768,16.022-37.215 c17.551-33.032,39.128-53.86,61.936-60.249V134.808z M450.717,141.18c17.874,30.193,28.427,64.199,30.749,99.804h-83.088 c-0.889-29.844-4.584-58.749-10.85-85.647C410.661,151.601,431.984,146.848,450.717,141.18z M415.783,96.216 c6.029,6.029,11.661,12.349,16.914,18.91c-16.073,4.389-33.972,8.114-53.204,11.112c-5.548-17.208-12.243-33.305-20.02-47.941 c-6.579-12.382-13.758-23.391-21.43-32.969C366.845,56.535,393.273,73.705,415.783,96.216z M271.016,271.016h97.259 c-1.004,28.268-4.686,55.49-10.81,80.612c-27.194-3.381-56.349-5.43-86.449-6.006V271.016z M271.016,240.984v-76.041 c30.005-0.394,59.257-2.261,86.656-5.464c6.125,25.403,9.756,52.932,10.659,81.505H271.016z M271.014,32.139h0.001 c22.808,6.389,44.384,27.217,61.936,60.249c6.178,11.627,11.601,24.318,16.24,37.848c-24.763,2.712-51.108,4.309-78.177,4.674 V32.139z M271.016,478.115V375.657c27.12,0.532,53.357,2.286,77.903,5.156c-4.579,13.232-9.911,25.654-15.967,37.053 C315.4,450.898,293.824,471.726,271.016,478.115z M415.783,415.784c-23.051,23.051-50.21,40.496-79.821,51.678 c8.457-10.156,16.34-22.011,23.51-35.504c7.62-14.341,14.198-30.088,19.68-46.906c19.465,3.213,37.473,7.186,53.515,11.859 C427.424,403.457,421.801,409.765,415.783,415.784z M450.606,371.009c-18.635-5.991-40-11.032-63.326-15.01 c6.296-26.68,10.048-55.36,11.041-84.983h83.146C479.139,306.694,468.549,340.769,450.606,371.009z"/></svg>';
		}

		if ( 'eye' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 576 512"><path d="M279.6 160.4C282.4 160.1 285.2 160 288 160C341 160 384 202.1 384 256C384 309 341 352 288 352C234.1 352 192 309 192 256C192 253.2 192.1 250.4 192.4 247.6C201.7 252.1 212.5 256 224 256C259.3 256 288 227.3 288 192C288 180.5 284.1 169.7 279.6 160.4zM480.6 112.6C527.4 156 558.7 207.1 573.5 243.7C576.8 251.6 576.8 260.4 573.5 268.3C558.7 304 527.4 355.1 480.6 399.4C433.5 443.2 368.8 480 288 480C207.2 480 142.5 443.2 95.42 399.4C48.62 355.1 17.34 304 2.461 268.3C-.8205 260.4-.8205 251.6 2.461 243.7C17.34 207.1 48.62 156 95.42 112.6C142.5 68.84 207.2 32 288 32C368.8 32 433.5 68.84 480.6 112.6V112.6zM288 112C208.5 112 144 176.5 144 256C144 335.5 208.5 400 288 400C367.5 400 432 335.5 432 256C432 176.5 367.5 112 288 112z"/></svg>';
		}
		
		if ( 'facebook' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><path d="M504 256C504 119 393 8 256 8S8 119 8 256c0 123.78 90.69 226.38 209.25 245V327.69h-63V256h63v-54.64c0-62.15 37-96.48 93.67-96.48 27.14 0 55.52 4.84 55.52 4.84v61h-31.28c-30.8 0-40.41 19.12-40.41 38.73V256h68.78l-11 71.69h-57.78V501C413.31 482.38 504 379.78 504 256z"/></svg>';
		}

		if ( 'twitter' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><path d="M459.37 151.716c.325 4.548.325 9.097.325 13.645 0 138.72-105.583 298.558-298.558 298.558-59.452 0-114.68-17.219-161.137-47.106 8.447.974 16.568 1.299 25.34 1.299 49.055 0 94.213-16.568 130.274-44.832-46.132-.975-84.792-31.188-98.112-72.772 6.498.974 12.995 1.624 19.818 1.624 9.421 0 18.843-1.3 27.614-3.573-48.081-9.747-84.143-51.98-84.143-102.985v-1.299c13.969 7.797 30.214 12.67 47.431 13.319-28.264-18.843-46.781-51.005-46.781-87.391 0-19.492 5.197-37.36 14.294-52.954 51.655 63.675 129.3 105.258 216.365 109.807-1.624-7.797-2.599-15.918-2.599-24.04 0-57.828 46.782-104.934 104.934-104.934 30.213 0 57.502 12.67 76.67 33.137 23.715-4.548 46.456-13.32 66.599-25.34-7.798 24.366-24.366 44.833-46.132 57.827 21.117-2.273 41.584-8.122 60.426-16.243-14.292 20.791-32.161 39.308-52.628 54.253z"/></svg>';
		}

		if ( 'instagram' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 448 512"><path d="M224.1 141c-63.6 0-114.9 51.3-114.9 114.9s51.3 114.9 114.9 114.9S339 319.5 339 255.9 287.7 141 224.1 141zm0 189.6c-41.1 0-74.7-33.5-74.7-74.7s33.5-74.7 74.7-74.7 74.7 33.5 74.7 74.7-33.6 74.7-74.7 74.7zm146.4-194.3c0 14.9-12 26.8-26.8 26.8-14.9 0-26.8-12-26.8-26.8s12-26.8 26.8-26.8 26.8 12 26.8 26.8zm76.1 27.2c-1.7-35.9-9.9-67.7-36.2-93.9-26.2-26.2-58-34.4-93.9-36.2-37-2.1-147.9-2.1-184.9 0-35.8 1.7-67.6 9.9-93.9 36.1s-34.4 58-36.2 93.9c-2.1 37-2.1 147.9 0 184.9 1.7 35.9 9.9 67.7 36.2 93.9s58 34.4 93.9 36.2c37 2.1 147.9 2.1 184.9 0 35.9-1.7 67.7-9.9 93.9-36.2 26.2-26.2 34.4-58 36.2-93.9 2.1-37 2.1-147.8 0-184.8zM398.8 388c-7.8 19.6-22.9 34.7-42.6 42.6-29.5 11.7-99.5 9-132.1 9s-102.7 2.6-132.1-9c-19.6-7.8-34.7-22.9-42.6-42.6-11.7-29.5-9-99.5-9-132.1s-2.6-102.7 9-132.1c7.8-19.6 22.9-34.7 42.6-42.6 29.5-11.7 99.5-9 132.1-9s102.7-2.6 132.1 9c19.6 7.8 34.7 22.9 42.6 42.6 11.7 29.5 9 99.5 9 132.1s2.7 102.7-9 132.1z"/></svg>';
		}

		if ( 'youtube' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 576 512"><path d="M549.655 124.083c-6.281-23.65-24.787-42.276-48.284-48.597C458.781 64 288 64 288 64S117.22 64 74.629 75.486c-23.497 6.322-42.003 24.947-48.284 48.597-11.412 42.867-11.412 132.305-11.412 132.305s0 89.438 11.412 132.305c6.281 23.65 24.787 41.5 48.284 47.821C117.22 448 288 448 288 448s170.78 0 213.371-11.486c23.497-6.321 42.003-24.171 48.284-47.821 11.412-42.867 11.412-132.305 11.412-132.305s0-89.438-11.412-132.305zm-317.51 213.508V175.185l142.739 81.205-142.739 81.201z"/></svg>';
		}

		if ( 'facebook_group' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 320 512"><path d="M279.14 288l14.22-92.66h-88.91v-60.13c0-25.35 12.42-50.06 52.24-50.06h40.42V6.26S260.43 0 225.36 0c-73.22 0-121.08 44.38-121.08 124.72v70.62H22.89V288h81.39v224h100.17V288z"/></svg>';
		}

		if ( 'vimeo' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 448 512"><path d="M447.8 153.6c-2 43.6-32.4 103.3-91.4 179.1-60.9 79.2-112.4 118.8-154.6 118.8-26.1 0-48.2-24.1-66.3-72.3C100.3 250 85.3 174.3 56.2 174.3c-3.4 0-15.1 7.1-35.2 21.1L0 168.2c51.6-45.3 100.9-95.7 131.8-98.5 34.9-3.4 56.3 20.5 64.4 71.5 28.7 181.5 41.4 208.9 93.6 126.7 18.7-29.6 28.8-52.1 30.2-67.6 4.8-45.9-35.8-42.8-63.3-31 22-72.1 64.1-107.1 126.2-105.1 45.8 1.2 67.5 31.1 64.9 89.4z"/></svg>';
		}

		if ( 'pinterest' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 496 512"><path d="M496 256c0 137-111 248-248 248-25.6 0-50.2-3.9-73.4-11.1 10.1-16.5 25.2-43.5 30.8-65 3-11.6 15.4-59 15.4-59 8.1 15.4 31.7 28.5 56.8 28.5 74.8 0 128.7-68.8 128.7-154.3 0-81.9-66.9-143.2-152.9-143.2-107 0-163.9 71.8-163.9 150.1 0 36.4 19.4 81.7 50.3 96.1 4.7 2.2 7.2 1.2 8.3-3.3.8-3.4 5-20.3 6.9-28.1.6-2.5.3-4.7-1.7-7.1-10.1-12.5-18.3-35.3-18.3-56.6 0-54.7 41.4-107.6 112-107.6 60.9 0 103.6 41.5 103.6 100.9 0 67.1-33.9 113.6-78 113.6-24.3 0-42.6-20.1-36.7-44.8 7-29.5 20.5-61.3 20.5-82.6 0-19-10.2-34.9-31.4-34.9-24.9 0-44.9 25.7-44.9 60.2 0 22 7.4 36.8 7.4 36.8s-24.5 103.8-29 123.2c-5 21.4-3 51.6-.9 71.2C65.4 450.9 0 361.1 0 256 0 119 111 8 248 8s248 111 248 248z"/></svg>';
		}

		if ( 'linkedin' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 448 512"><path d="M416 32H31.9C14.3 32 0 46.5 0 64.3v383.4C0 465.5 14.3 480 31.9 480H416c17.6 0 32-14.5 32-32.3V64.3c0-17.8-14.4-32.3-32-32.3zM135.4 416H69V202.2h66.5V416zm-33.2-243c-21.3 0-38.5-17.3-38.5-38.5S80.9 96 102.2 96c21.2 0 38.5 17.3 38.5 38.5 0 21.3-17.2 38.5-38.5 38.5zm282.1 243h-66.4V312c0-24.8-.5-56.7-34.5-56.7-34.6 0-39.9 27-39.9 54.9V416h-66.4V202.2h63.7v29.2h.9c8.9-16.8 30.6-34.5 62.9-34.5 67.2 0 79.7 44.3 79.7 101.9V416z"/></svg>';
		}

		if ( 'medium' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 640 512"><path d="M180.5,74.262C80.813,74.262,0,155.633,0,256S80.819,437.738,180.5,437.738,361,356.373,361,256,280.191,74.262,180.5,74.262Zm288.25,10.646c-49.845,0-90.245,76.619-90.245,171.095s40.406,171.1,90.251,171.1,90.251-76.619,90.251-171.1H559C559,161.5,518.6,84.908,468.752,84.908Zm139.506,17.821c-17.526,0-31.735,68.628-31.735,153.274s14.2,153.274,31.735,153.274S640,340.631,640,256C640,171.351,625.785,102.729,608.258,102.729Z"/></svg>';
		}

		if ( 'wordpress' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><path d="M61.7 169.4l101.5 278C92.2 413 43.3 340.2 43.3 256c0-30.9 6.6-60.1 18.4-86.6zm337.9 75.9c0-26.3-9.4-44.5-17.5-58.7-10.8-17.5-20.9-32.4-20.9-49.9 0-19.6 14.8-37.8 35.7-37.8.9 0 1.8.1 2.8.2-37.9-34.7-88.3-55.9-143.7-55.9-74.3 0-139.7 38.1-177.8 95.9 5 .2 9.7.3 13.7.3 22.2 0 56.7-2.7 56.7-2.7 11.5-.7 12.8 16.2 1.4 17.5 0 0-11.5 1.3-24.3 2l77.5 230.4L249.8 247l-33.1-90.8c-11.5-.7-22.3-2-22.3-2-11.5-.7-10.1-18.2 1.3-17.5 0 0 35.1 2.7 56 2.7 22.2 0 56.7-2.7 56.7-2.7 11.5-.7 12.8 16.2 1.4 17.5 0 0-11.5 1.3-24.3 2l76.9 228.7 21.2-70.9c9-29.4 16-50.5 16-68.7zm-139.9 29.3l-63.8 185.5c19.1 5.6 39.2 8.7 60.1 8.7 24.8 0 48.5-4.3 70.6-12.1-.6-.9-1.1-1.9-1.5-2.9l-65.4-179.2zm183-120.7c.9 6.8 1.4 14 1.4 21.9 0 21.6-4 45.8-16.2 76.2l-65 187.9C426.2 403 468.7 334.5 468.7 256c0-37-9.4-71.8-26-102.1zM504 256c0 136.8-111.3 248-248 248C119.2 504 8 392.7 8 256 8 119.2 119.2 8 256 8c136.7 0 248 111.2 248 248zm-11.4 0c0-130.5-106.2-236.6-236.6-236.6C125.5 19.4 19.4 125.5 19.4 256S125.6 492.6 256 492.6c130.5 0 236.6-106.1 236.6-236.6z"/></svg>';
		}

		if ( 'reddit' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><path d="M440.3 203.5c-15 0-28.2 6.2-37.9 15.9-35.7-24.7-83.8-40.6-137.1-42.3L293 52.3l88.2 19.8c0 21.6 17.6 39.2 39.2 39.2 22 0 39.7-18.1 39.7-39.7s-17.6-39.7-39.7-39.7c-15.4 0-28.7 9.3-35.3 22l-97.4-21.6c-4.9-1.3-9.7 2.2-11 7.1L246.3 177c-52.9 2.2-100.5 18.1-136.3 42.8-9.7-10.1-23.4-16.3-38.4-16.3-55.6 0-73.8 74.6-22.9 100.1-1.8 7.9-2.6 16.3-2.6 24.7 0 83.8 94.4 151.7 210.3 151.7 116.4 0 210.8-67.9 210.8-151.7 0-8.4-.9-17.2-3.1-25.1 49.9-25.6 31.5-99.7-23.8-99.7zM129.4 308.9c0-22 17.6-39.7 39.7-39.7 21.6 0 39.2 17.6 39.2 39.7 0 21.6-17.6 39.2-39.2 39.2-22 .1-39.7-17.6-39.7-39.2zm214.3 93.5c-36.4 36.4-139.1 36.4-175.5 0-4-3.5-4-9.7 0-13.7 3.5-3.5 9.7-3.5 13.2 0 27.8 28.5 120 29 149 0 3.5-3.5 9.7-3.5 13.2 0 4.1 4 4.1 10.2.1 13.7zm-.8-54.2c-21.6 0-39.2-17.6-39.2-39.2 0-22 17.6-39.7 39.2-39.7 22 0 39.7 17.6 39.7 39.7-.1 21.5-17.7 39.2-39.7 39.2z"/></svg>';
		}

		if ( 'patreon' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><path d="M512 194.8c0 101.3-82.4 183.8-183.8 183.8-101.7 0-184.4-82.4-184.4-183.8 0-101.6 82.7-184.3 184.4-184.3C429.6 10.5 512 93.2 512 194.8zM0 501.5h90v-491H0v491z"/></svg>';
		}

		if ( 'github' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 496 512"><path d="M165.9 397.4c0 2-2.3 3.6-5.2 3.6-3.3.3-5.6-1.3-5.6-3.6 0-2 2.3-3.6 5.2-3.6 3-.3 5.6 1.3 5.6 3.6zm-31.1-4.5c-.7 2 1.3 4.3 4.3 4.9 2.6 1 5.6 0 6.2-2s-1.3-4.3-4.3-5.2c-2.6-.7-5.5.3-6.2 2.3zm44.2-1.7c-2.9.7-4.9 2.6-4.6 4.9.3 2 2.9 3.3 5.9 2.6 2.9-.7 4.9-2.6 4.6-4.6-.3-1.9-3-3.2-5.9-2.9zM244.8 8C106.1 8 0 113.3 0 252c0 110.9 69.8 205.8 169.5 239.2 12.8 2.3 17.3-5.6 17.3-12.1 0-6.2-.3-40.4-.3-61.4 0 0-70 15-84.7-29.8 0 0-11.4-29.1-27.8-36.6 0 0-22.9-15.7 1.6-15.4 0 0 24.9 2 38.6 25.8 21.9 38.6 58.6 27.5 72.9 20.9 2.3-16 8.8-27.1 16-33.7-55.9-6.2-112.3-14.3-112.3-110.5 0-27.5 7.6-41.3 23.6-58.9-2.6-6.5-11.1-33.3 2.6-67.9 20.9-6.5 69 27 69 27 20-5.6 41.5-8.5 62.8-8.5s42.8 2.9 62.8 8.5c0 0 48.1-33.6 69-27 13.7 34.7 5.2 61.4 2.6 67.9 16 17.7 25.8 31.5 25.8 58.9 0 96.5-58.9 104.2-114.8 110.5 9.2 7.9 17 22.9 17 46.4 0 33.7-.3 75.4-.3 83.6 0 6.5 4.6 14.4 17.3 12.1C428.2 457.8 496 362.9 496 252 496 113.3 383.5 8 244.8 8zM97.2 352.9c-1.3 1-1 3.3.7 5.2 1.6 1.6 3.9 2.3 5.2 1 1.3-1 1-3.3-.7-5.2-1.6-1.6-3.9-2.3-5.2-1zm-10.8-8.1c-.7 1.3.3 2.9 2.3 3.9 1.6 1 3.6.7 4.3-.7.7-1.3-.3-2.9-2.3-3.9-2-.6-3.6-.3-4.3.7zm32.4 35.6c-1.6 1.3-1 4.3 1.3 6.2 2.3 2.3 5.2 2.6 6.5 1 1.3-1.3.7-4.3-1.3-6.2-2.2-2.3-5.2-2.6-6.5-1zm-11.4-14.7c-1.6 1-1.6 3.6 0 5.9 1.6 2.3 4.3 3.3 5.6 2.3 1.6-1.3 1.6-3.9 0-6.2-1.4-2.3-4-3.3-5.6-2z"/></svg>';
		}

		if ( 'dribbble' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><path d="M256 8C119.252 8 8 119.252 8 256s111.252 248 248 248 248-111.252 248-248S392.748 8 256 8zm163.97 114.366c29.503 36.046 47.369 81.957 47.835 131.955-6.984-1.477-77.018-15.682-147.502-6.818-5.752-14.041-11.181-26.393-18.617-41.614 78.321-31.977 113.818-77.482 118.284-83.523zM396.421 97.87c-3.81 5.427-35.697 48.286-111.021 76.519-34.712-63.776-73.185-116.168-79.04-124.008 67.176-16.193 137.966 1.27 190.061 47.489zm-230.48-33.25c5.585 7.659 43.438 60.116 78.537 122.509-99.087 26.313-186.36 25.934-195.834 25.809C62.38 147.205 106.678 92.573 165.941 64.62zM44.17 256.323c0-2.166.043-4.322.108-6.473 9.268.19 111.92 1.513 217.706-30.146 6.064 11.868 11.857 23.915 17.174 35.949-76.599 21.575-146.194 83.527-180.531 142.306C64.794 360.405 44.17 310.73 44.17 256.323zm81.807 167.113c22.127-45.233 82.178-103.622 167.579-132.756 29.74 77.283 42.039 142.053 45.189 160.638-68.112 29.013-150.015 21.053-212.768-27.882zm248.38 8.489c-2.171-12.886-13.446-74.897-41.152-151.033 66.38-10.626 124.7 6.768 131.947 9.055-9.442 58.941-43.273 109.844-90.795 141.978z"/></svg>';
		}

		if ( 'behance' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 576 512"><path d="M232 237.2c31.8-15.2 48.4-38.2 48.4-74 0-70.6-52.6-87.8-113.3-87.8H0v354.4h171.8c64.4 0 124.9-30.9 124.9-102.9 0-44.5-21.1-77.4-64.7-89.7zM77.9 135.9H151c28.1 0 53.4 7.9 53.4 40.5 0 30.1-19.7 42.2-47.5 42.2h-79v-82.7zm83.3 233.7H77.9V272h84.9c34.3 0 56 14.3 56 50.6 0 35.8-25.9 47-57.6 47zm358.5-240.7H376V94h143.7v34.9zM576 305.2c0-75.9-44.4-139.2-124.9-139.2-78.2 0-131.3 58.8-131.3 135.8 0 79.9 50.3 134.7 131.3 134.7 61.3 0 101-27.6 120.1-86.3H509c-6.7 21.9-34.3 33.5-55.7 33.5-41.3 0-63-24.2-63-65.3h185.1c.3-4.2.6-8.7.6-13.2zM390.4 274c2.3-33.7 24.7-54.8 58.5-54.8 35.4 0 53.2 20.8 56.2 54.8H390.4z"/></svg>';
		}

		if ( 'vk' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 448 512"><path d="M31.4907 63.4907C0 94.9813 0 145.671 0 247.04V264.96C0 366.329 0 417.019 31.4907 448.509C62.9813 480 113.671 480 215.04 480H232.96C334.329 480 385.019 480 416.509 448.509C448 417.019 448 366.329 448 264.96V247.04C448 145.671 448 94.9813 416.509 63.4907C385.019 32 334.329 32 232.96 32H215.04C113.671 32 62.9813 32 31.4907 63.4907ZM75.6 168.267H126.747C128.427 253.76 166.133 289.973 196 297.44V168.267H244.16V242C273.653 238.827 304.64 205.227 315.093 168.267H363.253C359.313 187.435 351.46 205.583 340.186 221.579C328.913 237.574 314.461 251.071 297.733 261.227C316.41 270.499 332.907 283.63 346.132 299.751C359.357 315.873 369.01 334.618 374.453 354.747H321.44C316.555 337.262 306.614 321.61 292.865 309.754C279.117 297.899 262.173 290.368 244.16 288.107V354.747H238.373C136.267 354.747 78.0267 284.747 75.6 168.267Z"/></svg>';
		}

		if ( 'xing' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 384 512"><path d="M162.7 210c-1.8 3.3-25.2 44.4-70.1 123.5-4.9 8.3-10.8 12.5-17.7 12.5H9.8c-7.7 0-12.1-7.5-8.5-14.4l69-121.3c.2 0 .2-.1 0-.3l-43.9-75.6c-4.3-7.8.3-14.1 8.5-14.1H100c7.3 0 13.3 4.1 18 12.2l44.7 77.5zM382.6 46.1l-144 253v.3L330.2 466c3.9 7.1.2 14.1-8.5 14.1h-65.2c-7.6 0-13.6-4-18-12.2l-92.4-168.5c3.3-5.8 51.5-90.8 144.8-255.2 4.6-8.1 10.4-12.2 17.5-12.2h65.7c8 0 12.3 6.7 8.5 14.1z"/></svg>';
		}

		if ( 'rss' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 448 512"><path d="M25.57 176.1C12.41 175.4 .9117 185.2 .0523 198.4s9.173 24.65 22.39 25.5c120.1 7.875 225.7 112.7 233.6 233.6C256.9 470.3 267.4 480 279.1 480c.5313 0 1.062-.0313 1.594-.0625c13.22-.8438 23.25-12.28 22.39-25.5C294.6 310.3 169.7 185.4 25.57 176.1zM32 32C14.33 32 0 46.31 0 64s14.33 32 32 32c194.1 0 352 157.9 352 352c0 17.69 14.33 32 32 32s32-14.31 32-32C448 218.6 261.4 32 32 32zM63.1 351.9C28.63 351.9 0 380.6 0 416s28.63 64 63.1 64s64.08-28.62 64.08-64S99.37 351.9 63.1 351.9z"/></svg>';
		}

		if ( 'email' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><path d="M207.8 20.73c-93.45 18.32-168.7 93.66-187 187.1c-27.64 140.9 68.65 266.2 199.1 285.1c19.01 2.888 36.17-12.26 36.17-31.49l.0001-.6631c0-15.74-11.44-28.88-26.84-31.24c-84.35-12.98-149.2-86.13-149.2-174.2c0-102.9 88.61-185.5 193.4-175.4c91.54 8.869 158.6 91.25 158.6 183.2l0 16.16c0 22.09-17.94 40.05-40 40.05s-40.01-17.96-40.01-40.05v-120.1c0-8.847-7.161-16.02-16.01-16.02l-31.98 .0036c-7.299 0-13.2 4.992-15.12 11.68c-24.85-12.15-54.24-16.38-86.06-5.106c-38.75 13.73-68.12 48.91-73.72 89.64c-9.483 69.01 43.81 128 110.9 128c26.44 0 50.43-9.544 69.59-24.88c24 31.3 65.23 48.69 109.4 37.49C465.2 369.3 496 324.1 495.1 277.2V256.3C495.1 107.1 361.2-9.332 207.8 20.73zM239.1 304.3c-26.47 0-48-21.56-48-48.05s21.53-48.05 48-48.05s48 21.56 48 48.05S266.5 304.3 239.1 304.3z"/></svg>';
		}

		if ( 'phone' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><path d="M511.2 387l-23.25 100.8c-3.266 14.25-15.79 24.22-30.46 24.22C205.2 512 0 306.8 0 54.5c0-14.66 9.969-27.2 24.22-30.45l100.8-23.25C139.7-2.602 154.7 5.018 160.8 18.92l46.52 108.5c5.438 12.78 1.77 27.67-8.98 36.45L144.5 207.1c33.98 69.22 90.26 125.5 159.5 159.5l44.08-53.8c8.688-10.78 23.69-14.51 36.47-8.975l108.5 46.51C506.1 357.2 514.6 372.4 511.2 387z"/></svg>';
		}

		if ( 'whatsapp' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 448 512"><path d="M380.9 97.1C339 55.1 283.2 32 223.9 32c-122.4 0-222 99.6-222 222 0 39.1 10.2 77.3 29.6 111L0 480l117.7-30.9c32.4 17.7 68.9 27 106.1 27h.1c122.3 0 224.1-99.6 224.1-222 0-59.3-25.2-115-67.1-157zm-157 341.6c-33.2 0-65.7-8.9-94-25.7l-6.7-4-69.8 18.3L72 359.2l-4.4-7c-18.5-29.4-28.2-63.3-28.2-98.2 0-101.7 82.8-184.5 184.6-184.5 49.3 0 95.6 19.2 130.4 54.1 34.8 34.9 56.2 81.2 56.1 130.5 0 101.8-84.9 184.6-186.6 184.6zm101.2-138.2c-5.5-2.8-32.8-16.2-37.9-18-5.1-1.9-8.8-2.8-12.5 2.8-3.7 5.6-14.3 18-17.6 21.8-3.2 3.7-6.5 4.2-12 1.4-32.6-16.3-54-29.1-75.5-66-5.7-9.8 5.7-9.1 16.3-30.3 1.8-3.7.9-6.9-.5-9.7-1.4-2.8-12.5-30.1-17.1-41.2-4.5-10.8-9.1-9.3-12.5-9.5-3.2-.2-6.9-.2-10.6-.2-3.7 0-9.7 1.4-14.8 6.9-5.1 5.6-19.4 19-19.4 46.3 0 27.3 19.9 53.7 22.6 57.4 2.8 3.7 39.1 59.7 94.8 83.8 35.2 15.2 49 16.5 66.6 13.9 10.7-1.6 32.8-13.4 37.4-26.4 4.6-13 4.6-24.1 3.2-26.4-1.3-2.5-5-3.9-10.5-6.6z"/></svg>';
		}

		if ( 'google_reviews' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 28"><path d="M12 12.281h11.328c.109.609.187 1.203.187 2C23.515 21.125 18.921 26 11.999 26c-6.641 0-12-5.359-12-12s5.359-12 12-12c3.234 0 5.953 1.188 8.047 3.141L16.78 8.282c-.891-.859-2.453-1.859-4.781-1.859-4.094 0-7.438 3.391-7.438 7.578s3.344 7.578 7.438 7.578c4.75 0 6.531-3.406 6.813-5.172h-6.813v-4.125z"/></svg>';
		}

		if ( 'google_play' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><path d="M325.3 234.3L104.6 13l280.8 161.2-60.1 60.1zM47 0C34 6.8 25.3 19.2 25.3 35.3v441.3c0 16.1 8.7 28.5 21.7 35.3l256.6-256L47 0zm425.2 225.6l-58.9-34.1-65.7 64.5 65.7 64.5 60.1-34.1c18-14.3 18-46.5-1.2-60.8zM104.6 499l280.8-161.2-60.1-60.1L104.6 499z"/></svg>';
		}

		if ( 'telegram' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 496 512"><path d="M248,8C111.033,8,0,119.033,0,256S111.033,504,248,504,496,392.967,496,256,384.967,8,248,8ZM362.952,176.66c-3.732,39.215-19.881,134.378-28.1,178.3-3.476,18.584-10.322,24.816-16.948,25.425-14.4,1.326-25.338-9.517-39.287-18.661-21.827-14.308-34.158-23.215-55.346-37.177-24.485-16.135-8.612-25,5.342-39.5,3.652-3.793,67.107-61.51,68.335-66.746.153-.655.3-3.1-1.154-4.384s-3.59-.849-5.135-.5q-3.283.746-104.608,69.142-14.845,10.194-26.894,9.934c-8.855-.191-25.888-5.006-38.551-9.123-15.531-5.048-27.875-7.717-26.8-16.291q.84-6.7,18.45-13.7,108.446-47.248,144.628-62.3c68.872-28.647,83.183-33.623,92.511-33.789,2.052-.034,6.639.474,9.61,2.885a10.452,10.452,0,0,1,3.53,6.716A43.765,43.765,0,0,1,362.952,176.66Z"/></svg>';
		}

		if ( 'yelp' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 384 512"><path d="M42.9 240.32l99.62 48.61c19.2 9.4 16.2 37.51-4.5 42.71L30.5 358.45a22.79 22.79 0 0 1-28.21-19.6 197.16 197.16 0 0 1 9-85.32 22.8 22.8 0 0 1 31.61-13.21zm44 239.25a199.45 199.45 0 0 0 79.42 32.11A22.78 22.78 0 0 0 192.94 490l3.9-110.82c.7-21.3-25.5-31.91-39.81-16.1l-74.21 82.4a22.82 22.82 0 0 0 4.09 34.09zm145.34-109.92l58.81 94a22.93 22.93 0 0 0 34 5.5 198.36 198.36 0 0 0 52.71-67.61A23 23 0 0 0 364.17 370l-105.42-34.26c-20.31-6.5-37.81 15.8-26.51 33.91zm148.33-132.23a197.44 197.44 0 0 0-50.41-69.31 22.85 22.85 0 0 0-34 4.4l-62 91.92c-11.9 17.7 4.7 40.61 25.2 34.71L366 268.63a23 23 0 0 0 14.61-31.21zM62.11 30.18a22.86 22.86 0 0 0-9.9 32l104.12 180.44c11.7 20.2 42.61 11.9 42.61-11.4V22.88a22.67 22.67 0 0 0-24.5-22.8 320.37 320.37 0 0 0-112.33 30.1z"/></svg>';
		}

		if ( 'twitch' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><path d="M391.17,103.47H352.54v109.7h38.63ZM285,103H246.37V212.75H285ZM120.83,0,24.31,91.42V420.58H140.14V512l96.53-91.42h77.25L487.69,256V0ZM449.07,237.75l-77.22,73.12H294.61l-67.6,64v-64H140.14V36.58H449.07Z"/></svg>';
		}

		if ( 'tiktok' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 448 512"><path d="M448,209.91a210.06,210.06,0,0,1-122.77-39.25V349.38A162.55,162.55,0,1,1,185,188.31V278.2a74.62,74.62,0,1,0,52.23,71.18V0l88,0a121.18,121.18,0,0,0,1.86,22.17h0A122.18,122.18,0,0,0,381,102.39a121.43,121.43,0,0,0,67,20.14Z"/></svg>';
		}

		if ( 'trip_advisor' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 36 28"><path d="M10.172 15.578c0 0.812-0.656 1.469-1.453 1.469-0.812 0-1.469-0.656-1.469-1.469 0-0.797 0.656-1.453 1.469-1.453 0.797 0 1.453 0.656 1.453 1.453zM28.203 15.563c0 0.812-0.656 1.469-1.469 1.469s-1.469-0.656-1.469-1.469 0.656-1.453 1.469-1.453 1.469 0.641 1.469 1.453zM11.953 15.578c0-1.656-1.359-3.016-3.016-3.016-1.672 0-3.016 1.359-3.016 3.016 0 1.672 1.344 3.016 3.016 3.016 1.656 0 3.016-1.344 3.016-3.016zM29.969 15.563c0-1.656-1.344-3.016-3.016-3.016-1.656 0-3.016 1.359-3.016 3.016 0 1.672 1.359 3.016 3.016 3.016 1.672 0 3.016-1.344 3.016-3.016zM13.281 15.578c0 2.406-1.937 4.359-4.344 4.359s-4.359-1.953-4.359-4.359c0-2.391 1.953-4.344 4.359-4.344s4.344 1.953 4.344 4.344zM31.313 15.563c0 2.406-1.953 4.344-4.359 4.344-2.391 0-4.344-1.937-4.344-4.344s1.953-4.344 4.344-4.344c2.406 0 4.359 1.937 4.359 4.344zM16.25 15.609c0-3.984-3.234-7.219-7.219-7.219-3.969 0-7.203 3.234-7.203 7.219s3.234 7.219 7.203 7.219c3.984 0 7.219-3.234 7.219-7.219zM26.688 6.656c-2.578-1.125-5.484-1.734-8.687-1.734s-6.391 0.609-8.953 1.719c4.953 0.016 8.953 4.016 8.953 8.969 0-4.859 3.859-8.813 8.687-8.953zM34.172 15.609c0-3.984-3.219-7.219-7.203-7.219s-7.219 3.234-7.219 7.219 3.234 7.219 7.219 7.219 7.203-3.234 7.203-7.219zM30.016 6.766h5.984c-0.938 1.094-1.625 2.562-1.797 3.578 1.078 1.484 1.719 3.297 1.719 5.266 0 4.953-4.016 8.953-8.953 8.953-2.812 0-5.313-1.281-6.953-3.297 0 0-0.734 0.875-2.016 2.797-0.219-0.453-1.328-2.031-2-2.812-1.641 2.031-4.156 3.313-6.969 3.313-4.937 0-8.953-4-8.953-8.953 0-1.969 0.641-3.781 1.719-5.266-0.172-1.016-0.859-2.484-1.797-3.578h5.703c3.063-2.047 7.516-3.328 12.297-3.328s8.953 1.281 12.016 3.328z"/></svg>';
		}

		if ( 'discord' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 640 512"><path d="M524.531,69.836a1.5,1.5,0,0,0-.764-.7A485.065,485.065,0,0,0,404.081,32.03a1.816,1.816,0,0,0-1.923.91,337.461,337.461,0,0,0-14.9,30.6,447.848,447.848,0,0,0-134.426,0,309.541,309.541,0,0,0-15.135-30.6,1.89,1.89,0,0,0-1.924-.91A483.689,483.689,0,0,0,116.085,69.137a1.712,1.712,0,0,0-.788.676C39.068,183.651,18.186,294.69,28.43,404.354a2.016,2.016,0,0,0,.765,1.375A487.666,487.666,0,0,0,176.02,479.918a1.9,1.9,0,0,0,2.063-.676A348.2,348.2,0,0,0,208.12,430.4a1.86,1.86,0,0,0-1.019-2.588,321.173,321.173,0,0,1-45.868-21.853,1.885,1.885,0,0,1-.185-3.126c3.082-2.309,6.166-4.711,9.109-7.137a1.819,1.819,0,0,1,1.9-.256c96.229,43.917,200.41,43.917,295.5,0a1.812,1.812,0,0,1,1.924.233c2.944,2.426,6.027,4.851,9.132,7.16a1.884,1.884,0,0,1-.162,3.126,301.407,301.407,0,0,1-45.89,21.83,1.875,1.875,0,0,0-1,2.611,391.055,391.055,0,0,0,30.014,48.815,1.864,1.864,0,0,0,2.063.7A486.048,486.048,0,0,0,610.7,405.729a1.882,1.882,0,0,0,.765-1.352C623.729,277.594,590.933,167.465,524.531,69.836ZM222.491,337.58c-28.972,0-52.844-26.587-52.844-59.239S193.056,219.1,222.491,219.1c29.665,0,53.306,26.82,52.843,59.239C275.334,310.993,251.924,337.58,222.491,337.58Zm195.38,0c-28.971,0-52.843-26.587-52.843-59.239S388.437,219.1,417.871,219.1c29.667,0,53.307,26.82,52.844,59.239C470.715,310.993,447.538,337.58,417.871,337.58Z"/></svg>';
		}

		if ( 'flickr' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 448 512"><path d="M400 32H48C21.5 32 0 53.5 0 80v352c0 26.5 21.5 48 48 48h352c26.5 0 48-21.5 48-48V80c0-26.5-21.5-48-48-48zM144.5 319c-35.1 0-63.5-28.4-63.5-63.5s28.4-63.5 63.5-63.5 63.5 28.4 63.5 63.5-28.4 63.5-63.5 63.5zm159 0c-35.1 0-63.5-28.4-63.5-63.5s28.4-63.5 63.5-63.5 63.5 28.4 63.5 63.5-28.4 63.5-63.5 63.5z"/></svg>';
		}

		if ( 'slack' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 448 512"><path d="M94.12 315.1c0 25.9-21.16 47.06-47.06 47.06S0 341 0 315.1c0-25.9 21.16-47.06 47.06-47.06h47.06v47.06zm23.72 0c0-25.9 21.16-47.06 47.06-47.06s47.06 21.16 47.06 47.06v117.84c0 25.9-21.16 47.06-47.06 47.06s-47.06-21.16-47.06-47.06V315.1zm47.06-188.98c-25.9 0-47.06-21.16-47.06-47.06S139 32 164.9 32s47.06 21.16 47.06 47.06v47.06H164.9zm0 23.72c25.9 0 47.06 21.16 47.06 47.06s-21.16 47.06-47.06 47.06H47.06C21.16 243.96 0 222.8 0 196.9s21.16-47.06 47.06-47.06H164.9zm188.98 47.06c0-25.9 21.16-47.06 47.06-47.06 25.9 0 47.06 21.16 47.06 47.06s-21.16 47.06-47.06 47.06h-47.06V196.9zm-23.72 0c0 25.9-21.16 47.06-47.06 47.06-25.9 0-47.06-21.16-47.06-47.06V79.06c0-25.9 21.16-47.06 47.06-47.06 25.9 0 47.06 21.16 47.06 47.06V196.9zM283.1 385.88c25.9 0 47.06 21.16 47.06 47.06 0 25.9-21.16 47.06-47.06 47.06-25.9 0-47.06-21.16-47.06-47.06v-47.06h47.06zm0-23.72c-25.9 0-47.06-21.16-47.06-47.06 0-25.9 21.16-47.06 47.06-47.06h117.84c25.9 0 47.06 21.16 47.06 47.06 0 25.9-21.16 47.06-47.06 47.06H283.1z"/></svg>';
		}

		if ( 'weibo' === $icon ) {
			$output = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><path d="M407 177.6c7.6-24-13.4-46.8-37.4-41.7-22 4.8-28.8-28.1-7.1-32.8 50.1-10.9 92.3 37.1 76.5 84.8-6.8 21.2-38.8 10.8-32-10.3zM214.8 446.7C108.5 446.7 0 395.3 0 310.4c0-44.3 28-95.4 76.3-143.7C176 67 279.5 65.8 249.9 161c-4 13.1 12.3 5.7 12.3 6 79.5-33.6 140.5-16.8 114 51.4-3.7 9.4 1.1 10.9 8.3 13.1 135.7 42.3 34.8 215.2-169.7 215.2zm143.7-146.3c-5.4-55.7-78.5-94-163.4-85.7-84.8 8.6-148.8 60.3-143.4 116s78.5 94 163.4 85.7c84.8-8.6 148.8-60.3 143.4-116zM347.9 35.1c-25.9 5.6-16.8 43.7 8.3 38.3 72.3-15.2 134.8 52.8 111.7 124-7.4 24.2 29.1 37 37.4 12 31.9-99.8-55.1-195.9-157.4-174.3zm-78.5 311c-17.1 38.8-66.8 60-109.1 46.3-40.8-13.1-58-53.4-40.3-89.7 17.7-35.4 63.1-55.4 103.4-45.1 42 10.8 63.1 50.2 46 88.5zm-86.3-30c-12.9-5.4-30 .3-38 12.9-8.3 12.9-4.3 28 8.6 34 13.1 6 30.8.3 39.1-12.9 8-13.1 3.7-28.3-9.7-34zm32.6-13.4c-5.1-1.7-11.4.6-14.3 5.4-2.9 5.1-1.4 10.6 3.7 12.9 5.1 2 11.7-.3 14.6-5.4 2.8-5.2 1.1-10.9-4-12.9z"/></svg>';
		}

		if ( 'kakaotalk' === $icon ) {
			$output = '<svg viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><path d="m9.462 9.306-.692 1.951h1.383z"/><path d="m12 1c-6.627 0-12 4.208-12 9.399 0 3.356 2.246 6.301 5.625 7.963-1.299 4.45-1.333 4.47-1.113 4.599.276.161.634-.005 5.357-3.311.692.097 1.404.148 2.131.148 6.627 0 12-4.208 12-9.399s-5.373-9.399-12-9.399zm-5.942 12.023c0 .362-.311.657-.692.657s-.692-.295-.692-.657v-4.086h-1.08c-.375 0-.679-.302-.679-.673s.303-.674.678-.674h3.545c.375 0 .679.302.679.673s-.305.674-.679.674h-1.08zm5.378.648c-.72 0-.587-.565-.919-1.195h-2.111c-.329.625-.2 1.195-.919 1.195-.693.001-.815-.421-.604-1.071l1.656-4.33c.117-.33.471-.669.922-.679.452.01.807.349.923.679 1.093 3.39 2.654 5.402 1.052 5.401zm3.939-.092h-2.221c-1.159 0-.454-1.565-.663-5.301 0-.379.317-.688.707-.688s.707.308.707.688v4.04h1.471c.366 0 .663.283.663.63-.001.348-.298.631-.664.631zm5.419-.518c-.025.181-.122.344-.269.454-.955.721-1.661-1.381-2.593-2.271l-.24.239v1.5c0 .38-.31.688-.693.688-.382 0-.692-.308-.692-.688v-4.705c0-.379.31-.688.692-.688s.692.308.692.688v1.478c1.277-.958 1.985-2.67 2.792-1.869.792.786-.848 1.474-1.527 2.422 1.604 2.212 1.909 2.267 1.838 2.752z"/></svg>';
		}

		if ( 'kakaostory' === $icon ) {
			$output = '<svg viewBox="0 0 100 100" xmlns="http://www.w3.org/2000/svg"><path d="M61.6,20h-24c-1.6,0-2.9,1.3-2.9,2.9v23.8c0,1.6,1.3,2.9,2.9,2.9h11c-0.1,2.8-1.3,5.9-3,8.6 c-1.9,3.1-6,6.5-6.1,6.5c-0.3,0.3-0.6,0.7-0.6,1.2c0,0.4,0.2,0.7,0.4,1l7.7,8.6c0,0,0.4,0.4,0.7,0.5c0.3,0.1,0.7,0.1,1-0.1 c13.3-10.3,15.3-23.1,15.6-30.1c0,0,0-22.8,0-22.8C64.5,21.3,63.2,20,61.6,20"/></svg>';
		}

		$output = apply_filters( 'olympus_svg_icon_list', $output, $icon );

		$classes = array(
			'oly-icon',
			'icon-' . $icon,
		);

		$output = sprintf(
			'<span class="%1$s">%2$s</span>',
			implode( ' ', $classes ),
			$output
		);

		return apply_filters( 'olympus_svg_icon', $output, $icon );
	}
}

/**
 * Check if we should include the default template part.
 *
 * @since 1.0.0
 * @param string $template The template to get.
 */
function olympus_do_template_part( $template ) {
	if ( apply_filters( 'olympus_do_template_part', true, $template ) ) {
		if ( 'archive' === $template || 'index' === $template ) {
			get_template_part( 'template-parts/content', get_post_format() );
		}

		if ( 'page' === $template ) {
			get_template_part( 'template-parts/content', 'page' );
		}

		if ( 'single' === $template ) {
			get_template_part( 'template-parts/content', 'single' );
		}

		if ( 'search' === $template ) {
			get_template_part( 'template-parts/content', 'search' );
		}

		if ( 'none' === $template ) {
			get_template_part( 'template-parts/content', 'none' );
		}

		if ( 'elementor_library' === $template ) {
			get_template_part( 'template-parts/content', 'elementor_library' );
		}
	}
}

if ( ! function_exists( 'olympus_blog_thumbnails' ) ) {
	/**
	 * Thumbnails blog style
	 *
	 * @since 1.1.1
	 */
	function olympus_blog_thumbnails() {
		if ( class_exists( 'Oly_Blog' ) && 'thumbnails' === olympus_get_option( 'archive_style' ) ) {
			$output = true;
		} else {
			$output = false;
		}

		return apply_filters( 'olympus_blog_thumbnails', $output );
	}
}

if ( ! function_exists( 'olympus_show_excerpt' ) ) {
	/**
	 * Figure out if we should show the blog excerpts or full posts
	 *
	 * @since 1.1.1
	 */
	function olympus_show_excerpt() {
		global $post;

		// Check to see if the more tag is being used.
		$more_tag = apply_filters( 'olympus_more_tag', strpos( $post->post_content, '<!--more-->' ) );

		$format = ( false !== get_post_format() ) ? get_post_format() : 'standard';

		if ( class_exists( 'Oly_Blog' ) && true === olympus_get_option( 'archive_type' ) ) {
			$show_excerpt = false;
		} else {
			$show_excerpt = true;
		}

		$show_excerpt = ( 'standard' !== $format ) ? false : $show_excerpt;

		$show_excerpt = ( $more_tag ) ? false : $show_excerpt;

		return apply_filters( 'olympus_show_excerpt', $show_excerpt );
	}
}

if ( ! function_exists( 'olympus_excerpt_more' ) ) {
	/**
	 * Prints the read more HTML to post excerpts.
	 *
	 * @since 1.0.0
	 *
	 * @param string $more The string shown within the more link.
	 * @return string The HTML for the more link.
	 */
	function olympus_excerpt_more( $more ) {
		$read_more_text    = apply_filters( 'olympus_post_read_more', esc_html__( 'Read More &raquo;', 'olympuswp' ) );
		$read_more_classes = apply_filters( 'olympus_post_read_more_class', array( 'read-more-link' ) );

		$output = ' &hellip;<p class="read-more"><a class="' . esc_attr( implode( ' ', $read_more_classes ) ) . '" href="' . esc_url( get_permalink() ) . '"> ' . the_title( '<span class="screen-reader-text">', '</span>', false ) . $read_more_text . '</a></p>';

		return apply_filters( 'olympus_excerpt_more_output', $output );
	}
	add_filter( 'excerpt_more', 'olympus_excerpt_more' );
}

if ( ! function_exists( 'olympus_post_heading' ) ) {

	/**
	 * Get post heading
	 *
	 * @return html Markup.
	 */
	function olympus_post_heading() {
		$tag = apply_filters( 'olympus_post_heading_tag', 'h2' );
		?>
		<header class="entry-header">
			<<?php echo esc_attr( $tag ); ?> class="entry-title" <?php olympus_do_microdata( 'name' ); ?>>
				<a href="<?php the_permalink(); ?>" rel="bookmark" <?php olympus_do_microdata( 'url' ); ?>><?php the_title(); ?></a>
			</<?php echo esc_attr( $tag ); ?>>
			<?php olympus_get_post_meta(); ?>
		</header><!-- .entry-header -->
		<?php
	}
}

if ( ! function_exists( 'olympus_post_structure' ) ) {

	/**
	 * Get post structure
	 *
	 * @return html Markup.
	 */
	function olympus_post_structure() {
		$structure = olympus_get_option( 'archive_structure' );
		if ( is_array( $structure ) ) {
			foreach ( $structure as $order ) { // phpcs:ignore WordPress.WP.GlobalVariablesOverride.Prohibited
				switch ( $order ) {
					// Featured Image.
					case 'image':
						olympus_post_thumbnail();
						break;

					// Title and Meta.
					case 'title-meta':
						olympus_post_heading();
						break;
				}
			}
		}
	}
}

if ( ! function_exists( 'olympus_single_post_heading' ) ) {

	/**
	 * Get single_post heading
	 *
	 * @return html Markup.
	 */
	function olympus_single_post_heading() {
		$tag = apply_filters( 'olympus_single_post_heading_tag', 'h2' );
		?>
		<header class="entry-header">
			<<?php echo esc_attr( $tag ); ?> class="entry-title">
				<?php the_title(); ?>
			</<?php echo esc_attr( $tag ); ?>>
			<?php olympus_single_get_post_meta(); ?>
		</header><!-- .entry-header -->
		<?php
	}
}

if ( ! function_exists( 'olympus_single_post_structure' ) ) {

	/**
	 * Get single post structure
	 *
	 * @return html Markup.
	 */
	function olympus_single_post_structure() {
		$structure = olympus_get_option( 'single_post_structure' );
		if ( is_array( $structure ) ) {
			foreach ( $structure as $order ) {
				switch ( $order ) {
					// Featured Image.
					case 'image':
						olympus_post_thumbnail();
						break;

					// Title and Meta.
					case 'title-meta':
						olympus_single_post_heading();
						break;
				}
			}
		}
	}
}

if ( ! function_exists( 'olympus_post_author' ) ) {

	/**
	 * Function to get author meta
	 *
	 * @return html Markup.
	 */
	function olympus_post_author() {
		$output = '';
		$output .= '<li class="post-meta-author posted-by vcard author">';
		$output .= olympus_get_svg_icon( 'meta-author' );
		$output .= '<a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '" title="' . esc_attr( sprintf( esc_html__( 'View all posts by %s', 'olympuswp' ), get_the_author() ) ) . '" rel="author" itemprop="url">' . esc_html( get_the_author() ) . '</a>';
		$output .= '</li>';
		return apply_filters( 'olympus_post_author_output', $output );
	}
}

if ( ! function_exists( 'olympus_post_date' ) ) {

	/**
	 * Function to get date meta
	 *
	 * @return html Markup.
	 */
	function olympus_post_date() {
		$output = '';
		$time_string = esc_html( get_the_date() );
		$modified_date = esc_html( get_the_modified_date() );
		$output .= '<li class="post-meta-date posted-on">';
		$output .= olympus_get_svg_icon( 'meta-date' );
		$output .= '<span class="published" itemprop="datePublished">' . $time_string . '</span>';
		$output .= '<span class="updated" itemprop="dateModified">' . $modified_date . '</span>';
		$output .= '</li>';
		return apply_filters( 'olympus_post_date_output', $output );
	}
}

if ( ! function_exists( 'olympus_post_cat' ) ) {

	/**
	 * Function to get cat meta
	 *
	 * @return html Markup.
	 */
	function olympus_post_cat() {
		$output = '';

		/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list( esc_html__( ', ', 'olympuswp' ) );

		if ( $categories_list ) {
			$output .= '<li class="post-meta-cat">';
			$output .= olympus_get_svg_icon( 'meta-cat' );
			$output .= '<span class="cat-links">' . $categories_list . '</span>';
			$output .= '</li>';
		}
		return apply_filters( 'olympus_post_cat_output', $output );
	}
}

if ( ! function_exists( 'olympus_post_comments' ) ) {

	/**
	 * Function to get comments meta
	 *
	 * @return html Markup.
	 */
	function olympus_post_comments() {
		$output = '';

		ob_start();
		if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			?>
			<li class="post-meta-comments">
				<?php
				echo olympus_get_svg_icon( 'meta-comments' );
				comments_popup_link( esc_html__( 'Leave a comment', 'olympuswp' ), esc_html__( '1 Comment', 'olympuswp' ), esc_html__( '% Comments', 'olympuswp' ) );
				?>
			</li>
			<?php
		}

		$output = ob_get_clean();
		return apply_filters( 'olympus_post_comments_output', $output );
	}
}

if ( ! function_exists( 'olympus_post_meta' ) ) {
	/**
	 * Post meta
	 *
	 * @param  string $post_meta Post meta.
	 * @return string post meta markup.
	 */
	function olympus_post_meta( $post_meta ) {
		$output = '';
		$loop_count = 1;

		foreach ( $post_meta as $meta_value ) {
			switch ( $meta_value ) {
				case 'author':
					$author = get_the_author();
					if ( ! empty( $author ) ) {
						$output .= olympus_post_author();
					}
					break;
				case 'date':
					$output .= olympus_post_date();
					break;
				case 'cat':
					$category = olympus_post_cat();
					if ( '' !== $category ) {
						$output .= $category;
					}
					break;
				case 'comments':
					$comment = olympus_post_comments();
					if ( '' !== $comment ) {
						$output .= $comment;
					}
					break;
				default:
					$output = apply_filters( 'olympus_meta_case_' . $meta_value, $output, $loop_count );
			}
			$loop_count ++;
		}

		return $output;
	}
}

if ( ! function_exists( 'olympus_get_post_meta' ) ) {

	/**
	 * Prints HTML with meta information.
	 *
	 * @param boolean $echo   Output print or return.
	 * @return string|void
	 */
	function olympus_get_post_meta( $echo = true ) {
		$enable_meta       = apply_filters( 'olympus_post_meta_enabled', '__return_true' );
		$post_meta         = olympus_get_option( 'archive_meta' );
		$current_post_type = get_post_type();
		$post_type_array   = apply_filters( 'olympus_post_type_meta', array( 'post' ) );

		$output = '';
		if ( is_array( $post_meta ) && ( in_array( $current_post_type, $post_type_array ) || 'attachment' == $current_post_type ) && $enable_meta ) {
			$output_str = olympus_post_meta( $post_meta );
			if ( ! empty( $output_str ) ) {
				$output = apply_filters( 'olympus_post_meta', '<div class="entry-meta"><ul>' . $output_str . '</ul></div>', $output_str ); // WPCS: XSS OK.
			}
		}
		if ( $echo ) {
			echo $output; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		} else {
			return $output;
		}
	}
}

if ( ! function_exists( 'olympus_single_get_post_meta' ) ) {

	/**
	 * Prints HTML with meta information.
	 *
	 * @param boolean $echo   Output print or return.
	 * @return string|void
	 */
	function olympus_single_get_post_meta( $echo = true ) {
		$enable_meta       = apply_filters( 'olympus_single_post_meta_enabled', '__return_true' );
		$post_meta         = olympus_get_option( 'single_meta' );
		$current_post_type = get_post_type();
		$post_type_array   = apply_filters( 'olympus_single_post_type_meta', array( 'post' ) );

		$output = '';
		if ( is_array( $post_meta ) && ( in_array( $current_post_type, $post_type_array ) || 'attachment' == $current_post_type ) && $enable_meta ) {
			$output_str = olympus_post_meta( $post_meta );
			if ( ! empty( $output_str ) ) {
				$output = apply_filters( 'olympus_single_post_meta', '<div class="entry-meta"><ul>' . $output_str . '</ul></div>', $output_str ); // WPCS: XSS OK.
			}
		}
		if ( $echo ) {
			echo $output; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		} else {
			return $output;
		}
	}
}

if ( ! function_exists( 'olympus_post_navigation_template' ) ) {
	/**
	 * Added this filter to modify the post navigation template to remove the h2 tag from screen reader text.
	 *
	 * @since 1.0.0
	 */
	function olympus_post_navigation_template() {

		$new_template = '
		        <nav class="navigation %1$s" role="navigation" aria-label="%4$s">
		                <span class="screen-reader-text">%2$s</span>
		                <div class="nav-links">%3$s</div>
		        </nav>';

		return $new_template;

	}
	add_filter( 'navigation_markup_template', 'olympus_post_navigation_template' );
}

if ( ! function_exists( 'olympus_single_post_nav' ) ) {
	/**
	 * Get Post Navigation
	 *
	 * Checks post navigation, if exists return as button.
	 *
	 * @since 1.0.0
	 *
	 * @return mixed Post Navigation Buttons
	 */
	function olympus_single_post_nav() {

		/* translators: used to get the icon */
		$nav_next = esc_html__( 'Next %s', 'olympuswp' ) . olympus_get_svg_icon( 'nav-right-arrow' );
		/* translators: used to get the icon */
		$nav_prev = olympus_get_svg_icon( 'nav-left-arrow' ) . esc_html__( 'Previous %s', 'olympuswp' );

		if ( is_rtl() ) {
			/* translators: used to get the icon */
			$nav_next = esc_html__( 'Next %s', 'olympuswp' ) . olympus_get_svg_icon( 'nav-left-arrow' );
			/* translators: used to get the icon */
			$nav_prev = olympus_get_svg_icon( 'nav-right-arrow' ) . esc_html__( 'Previous %s', 'olympuswp' );
		}

		$post_obj = get_post_type_object( get_post_type() );

		$next_text = sprintf(
			$nav_next,
			$post_obj->labels->singular_name
		);

		$prev_text = sprintf(
			$nav_prev,
			$post_obj->labels->singular_name
		);

		/**
		 * Filter the post pagination markup
		 */
		the_post_navigation(
			apply_filters(
				'olympus_single_post_navigation',
				array(
					'next_text' => $next_text,
					'prev_text' => $prev_text,
				)
			)
		);

	}
}

if ( ! function_exists( 'olympus_comment_form_default_fields' ) ) {
	/**
	 * Function filter comment form's default fields.
	 *
	 * @since 1.0.0
	 *
	 * @param array $fields Array of comment form's default fields.
	 * @return array        Comment form fields.
	 */
	function olympus_comment_form_default_fields( $fields ) {
		$commenter = wp_get_current_commenter();
		$req       = get_option( 'require_name_email' );
		$aria_req  = ( $req ? " aria-required='true'" : '' );

		$fields['author'] = '<div class="olympus-comment-wrap oly-row"><p class="comment-form-author oly-col">' .
					'<label for="author" class="screen-reader-text">' . esc_html( esc_html__( 'Name*', 'olympuswp' ) ) . '</label><input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) .
					'" placeholder="' . esc_attr( esc_html__( 'Name*', 'olympuswp' ) ) . '" size="30"' . $aria_req . ' /></p>';
		$fields['email']  = '<p class="comment-form-email oly-col">' .
					'<label for="email" class="screen-reader-text">' . esc_html( esc_html__( 'Email*', 'olympuswp' ) ) . '</label><input id="email" name="email" type="text" value="' . esc_attr( $commenter['comment_author_email'] ) .
					'" placeholder="' . esc_attr( esc_html__( 'Email*', 'olympuswp' ) ) . '" size="30"' . $aria_req . ' /></p>';
		$fields['url']    = '<p class="comment-form-url oly-col">' .
					'<label for="url" class="screen-reader-text">' . esc_html( esc_html__( 'Website', 'olympuswp' ) ) . '</label><input id="url" name="url" type="text" value="' . esc_url( $commenter['comment_author_url'] ) .
					'" placeholder="' . esc_attr( esc_html__( 'Website', 'olympuswp' ) ) . '" size="30" /></label></p></div>';

		return apply_filters( 'olympus_comment_form_default_fields', $fields );
	}
	add_filter( 'comment_form_default_fields', 'olympus_comment_form_default_fields' );
}

if ( ! function_exists( 'olympus_content_nav' ) ) {
	/**
	 * Display navigation to next/previous pages when applicable.
	 *
	 * @since 1.0.0
	 *
	 * @param string $nav_id The id of our navigation.
	 */
	function olympus_content_nav( $nav_id ) {
		global $wp_query, $post;

		// Don't print empty markup on single pages if there's nowhere to navigate.
		if ( is_single() ) {
			$previous = ( is_attachment() ) ? get_post( $post->post_parent ) : get_adjacent_post( false, '', true );
			$next = get_adjacent_post( false, '', false );

			if ( ! $next && ! $previous ) {
				return;
			}
		}

		// Don't print empty markup in archives if there's only one page.
		if ( $wp_query->max_num_pages < 2 && ( is_home() || is_archive() || is_search() ) ) {
			return;
		}
		?>
		<nav id="<?php echo esc_attr( $nav_id ); ?>" class="paging-navigation">
			<span class="screen-reader-text"><?php esc_html_e( 'Post navigation', 'olympuswp' ); ?></span>

			<?php
			if ( is_home() || is_archive() || is_search() ) : // navigation links for home, archive, and search pages.

				if ( function_exists( 'the_posts_pagination' ) ) {
					the_posts_pagination(
						array(
							'mid_size' => apply_filters( 'olympus_pagination_mid_size', 1 ),
							'prev_text' => apply_filters(
								'olympus_previous_link_text',
								sprintf(
									/* translators: left arrow */
									__( '%s Previous', 'olympuswp' ),
									'<span aria-hidden="true">&larr;</span>'
								)
							),
							'next_text' => apply_filters(
								'olympus_next_link_text',
								sprintf(
									/* translators: right arrow */
									__( 'Next %s', 'olympuswp' ),
									'<span aria-hidden="true">&rarr;</span>'
								)
							),
							'before_page_number' => sprintf(
								'<span class="screen-reader-text">%s</span>',
								_x( 'Page', 'prepends the pagination page number for screen readers', 'olympuswp' )
							),
						)
					);
				}
			endif;
			?>
		</nav>
		<?php
	}
}

/**
 * Add our post navigation after post loops.
 *
 * @since 1.0.0
 * @param string $template The template of the current action.
 */
function olympus_do_post_navigation( $template ) {
	$templates = apply_filters(
		'olympus_post_navigation_templates',
		array(
			'index',
			'archive',
			'search',
		)
	);

	if ( in_array( $template, $templates ) && apply_filters( 'olympus_show_post_navigation', true ) ) {
		echo olympus_content_nav( 'oly-pagination' ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
	}
}
add_action( 'olympus_after_loop', 'olympus_do_post_navigation' );

if ( ! function_exists( 'olympus_comment_form_defaults' ) ) {
	/**
	 * Function filter comment form arguments.
	 *
	 * @since 1.0.0
	 *
	 * @param array $args   Comment form arguments.
	 * @return array
	 */
	function olympus_comment_form_defaults( $args ) {
		if ( 'post' == get_post_type() ) {
			$args['id_form']           = 'oly-commentform';
			$args['title_reply']       = esc_html__( 'Leave a Comment', 'olympuswp' );
			$args['cancel_reply_link'] = esc_html__( 'Cancel Reply', 'olympuswp' );
			$args['label_submit']      = esc_html__( 'Post Comment &raquo;', 'olympuswp' );
			$args['comment_field']     = '<div class="oly-row comment-textarea"><p class="comment-form-textarea oly-col"><label for="comment" class="screen-reader-text">' . esc_html( esc_html__( 'Type here..', 'olympuswp' ) ) . '</label><textarea id="comment" name="comment" placeholder="' . esc_attr( esc_html__( 'Type here..', 'olympuswp' ) ) . '" cols="45" rows="8" aria-required="true"></textarea></p></div>';
		}
		return apply_filters( 'olympus_comment_form_defaults', $args );
	}
	add_filter( 'comment_form_defaults', 'olympus_comment_form_defaults' );
}

if ( ! function_exists( 'olympus_enqueue_meta_box_scripts' ) ) {
	/**
	 * Adds any scripts for this meta box.
	 *
	 * @param string $hook The current admin page.
	 *
	 * @since 1.0.0
	 */
	function olympus_enqueue_meta_box_scripts( $hook ) {
		if ( in_array( $hook, array( 'post.php', 'post-new.php' ) ) ) {
			$post_types = get_post_types( array( 'public' => true ) );
			$screen = get_current_screen();
			$post_type = $screen->id;

			if ( in_array( $post_type, (array) $post_types ) ) {
				wp_enqueue_style( 'olympus-layout-metabox', OLY_THEME_URI . 'assets/css/admin/meta-box.css', array(), OLY_VERSION );
			}
		}
	}
	add_action( 'admin_enqueue_scripts', 'olympus_enqueue_meta_box_scripts' );
}

if ( ! function_exists( 'olympus_list_comments' ) ) {
	/**
	 * Template for comments and pingbacks.
	 *
	 * @param  string $comment Comment.
	 * @param  array  $args    Comment arguments.
	 * @param  number $depth   Depth.
	 * @return mixed          Comment markup.
	 *
	 * @since 1.0.0
	 */
	function olympus_list_comments( $comment, $args, $depth ) {
		$commenter          = wp_get_current_commenter();
		$show_pending_links = ! empty( $commenter['comment_author'] );
		?>
		<li id="comment-<?php comment_ID(); ?>" <?php comment_class(); ?>>
			<article id="div-comment-<?php comment_ID(); ?>" class="comment-body">
				<div class="comment-info">
					<div class="comment-avatar">
						<?php
						if ( 0 != $args['avatar_size'] ) {
							echo get_avatar( $comment, $args['avatar_size'] );
						}
						?>
					</div><!-- .comment-avatar -->

					<header class="comment-meta">
						<div class="comment-author vcard">
							<?php
							$comment_author = get_comment_author_link( $comment );

							if ( '0' == $comment->comment_approved && ! $show_pending_links ) {
								$comment_author = get_comment_author( $comment );
							}

							printf(
								/* translators: %s: Comment author link. */
								'<b itemprop="name" class="fn">%s</b>',
								$comment_author // phpcs:ignore
							);
							?>
						</div><!-- .comment-avatar -->

						<div class="comment-date">
							<?php
							printf(
								'<a href="%s"><time datetime="%s">%s</time></a>',
								esc_url( get_comment_link( $comment, $args ) ),
								get_comment_time( 'c' ), // phpcs:ignore
								sprintf(
									/* translators: 1: Comment date, 2: Comment time. */
									__( '%1$s at %2$s', 'olympuswp' ), // phpcs:ignore
									get_comment_date( '', $comment ), // phpcs:ignore
									get_comment_time() // phpcs:ignore
								)
							);
							?>
						</div><!-- .comment-date -->
					</header><!-- .comment-meta -->
				</div><!-- .comment-info -->

				<section class="comment-content">
					<?php comment_text(); ?>
				</section><!-- .comment-content -->

				<div class="comment-links">
					<?php
					edit_comment_link( esc_html__( 'Edit', 'olympuswp' ), ' <span class="edit-link">', '</span>' );

					if ( '1' == $comment->comment_approved || $show_pending_links ) {
						comment_reply_link(
							array_merge(
								$args,
								array(
									'add_below' => 'div-comment',
									'depth'     => $depth,
									'max_depth' => $args['max_depth'],
									'before'    => '<span class="reply-link">',
									'after'     => '</span>',
								)
							)
						);
					}
					?>
				</div>

				<?php if ( '0' == $comment->comment_approved ) : ?>
					<em class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'olympuswp' ); ?></em>
				<?php endif; ?>
			</article><!-- .comment-body -->
		<?php
	}
}

if ( ! function_exists( 'olympus_register_meta_box' ) ) {
	/**
	 * Generate the layout metabox
	 *
	 * @since 1.0.0
	 */
	function olympus_register_metabox() {
		if ( ! current_user_can( 'edit_theme_options' ) ) {
			return;
		}

		global $post;

		$blog_id = get_option( 'page_for_posts' );

		// No need for the Layout metabox on the blog page.
		if ( $blog_id && (int) $blog_id === (int) $post->ID ) {
			return;
		}

		$post_types = get_post_types( array( 'public' => true ) );

		foreach ( $post_types as $type ) {
			if ( 'attachment' !== $type ) {
				add_meta_box(
					'olympus_options_metabox',
					apply_filters( 'olympus_metabox_title', esc_html__( 'Olympus', 'olympuswp' ) ) . ' ' . esc_html__( 'Settings', 'olympuswp' ),
					'olympus_do_metabox',
					$type,
					'side'
				);
			}
		}
	}
	add_action( 'add_meta_boxes', 'olympus_register_metabox' );
}

if ( ! function_exists( 'olympus_do_metabox' ) ) {
	/**
	 * Build our meta box.
	 *
	 * @param object $post All post information.
	 *
	 * @since 1.0.0
	 */
	function olympus_do_metabox( $post ) {
		wp_nonce_field( basename( __FILE__ ), 'olympus_metabox_nonce' );

		$meta = (array) get_post_meta( $post->ID );
		$layout = ( isset( $meta['olympus-layout-meta'][0] ) ) ? $meta['olympus-layout-meta'][0] : '';
		$title = ( isset( $meta['olympus-disable-title'][0] ) ) ? $meta['olympus-disable-title'][0] : '';
		?>

		<div id="olympus-metabox-container">
			<div class="olympus-metabox-content">
				<div id="olympus-metabox-sidebars">
					<div class="olympus_layouts">
						<label for="olympus-sidebar-layout" class="olympus-metabox-section-title"><?php esc_html_e( 'Sidebar Layout', 'olympuswp' ); ?></label>

						<select name="olympus-layout-meta" id="olympus-sidebar-layout">
							<option value="" <?php selected( $layout, '' ); ?>><?php esc_html_e( 'Default', 'olympuswp' ); ?></option>
							<option value="no-sidebar" <?php selected( $layout, 'no-sidebar' ); ?>><?php esc_html_e( 'No Sidebars', 'olympuswp' ); ?></option>
							<option value="full-width" <?php selected( $layout, 'full-width' ); ?>><?php esc_html_e( 'Full Width', 'olympuswp' ); ?></option>
							<option value="right-sidebar" <?php selected( $layout, 'right-sidebar' ); ?>><?php esc_html_e( 'Right Sidebar', 'olympuswp' ); ?></option>
							<option value="left-sidebar" <?php selected( $layout, 'left-sidebar' ); ?>><?php esc_html_e( 'Left Sidebar', 'olympuswp' ); ?></option>
						</select>
					</div>
				</div>

				<div id="olympus-metabox-disable-elements">
					<label class="olympus-metabox-section-title"><?php esc_html_e( 'Disable Elements', 'olympuswp' ); ?></label>
					<?php
					if ( ! class_exists( 'Oly_Disable_Elements' ) ) {
						?>
						<div class="olympus_disable_elements">
							<label for="meta-olympus-disable-title" title="<?php esc_attr_e( 'Content Title', 'olympuswp' ); ?>">
								<input type="checkbox" name="olympus-disable-title" id="meta-olympus-disable-title" value="true" <?php checked( $title, 'true' ); ?>>
								<?php esc_html_e( 'Page Header', 'olympuswp' ); ?>
							</label>

							<?php
							if ( ! defined( 'OLY_PRO_VERSION' ) ) {
								?>
								<span style="display:block;padding-top:1em;margin-top:1em;border-top:1px solid #efefef;">
									<a href="<?php echo olympus_get_premium_url( 'https://wpolympus.com/pro' ); ?>" target="_blank"><?php esc_html_e( 'Pro module available', 'olympuswp' ); ?></a>
								</span>
								<?php
							} ?>
						</div>
						<?php
					}
					
					do_action( 'olympus_metabox_disable_elements_section', $meta ); ?>
				</div>
				<?php do_action( 'olympus_metabox_content', $meta ); ?>
			</div>
		</div>

		<?php
	}
}

if ( ! function_exists( 'olympus_save_metadata' ) ) {
	/**
	 * Saves the sidebar metabox meta data.
	 *
	 * @param string $post_id The option name to look up.
	 *
	 * @since 1.0.0
	 */
	function olympus_save_metadata( $post_id ) {
		$is_autosave = wp_is_post_autosave( $post_id );
		$is_revision = wp_is_post_revision( $post_id );
		$is_valid_nonce = ( isset( $_POST['olympus_metabox_nonce'] ) && wp_verify_nonce( sanitize_key( $_POST['olympus_metabox_nonce'] ), basename( __FILE__ ) ) ) ? true : false;

		if ( $is_autosave || $is_revision || ! $is_valid_nonce ) {
			return;
		}

		if ( ! current_user_can( 'edit_post', $post_id ) ) {
			return $post_id;
		}

		$sidebar_key   = 'olympus-layout-meta';
		$sidebar_value = filter_input( INPUT_POST, $sidebar_key, FILTER_SANITIZE_STRING );

		if ( $sidebar_value ) {
			update_post_meta( $post_id, $sidebar_key, $sidebar_value );
		} else {
			delete_post_meta( $post_id, $sidebar_key );
		}

		$disable_content_title_key   = 'olympus-disable-title';
		$disable_content_title_value = filter_input( INPUT_POST, $disable_content_title_key, FILTER_SANITIZE_STRING );

		if ( $disable_content_title_value ) {
			update_post_meta( $post_id, $disable_content_title_key, $disable_content_title_value );
		} else {
			delete_post_meta( $post_id, $disable_content_title_key );
		}

		do_action( 'olympus_metabox_save', $post_id );
	}
	add_action( 'save_post', 'olympus_save_metadata' );
}

if ( ! function_exists( 'olympus_get_defaults' ) ) {
	/**
	 * Set default options
	 *
	 * @since 1.0.0
	 */
	function olympus_get_defaults() {
		$defaults = array(
			'show_site_title' => false,
			'show_tagline' => false,
			'add_retina_logo' => false,
			'retina_logo' => '',
			'logo_width' => array(
				'desktop' => '',
				'tablet'  => '',
				'mobile'  => '',
			),
			'logo_width_unit' => 'px',
			'logo_url' => '',
			'remove_container' => false,
			'search_style' => 'none',
			'search_fullscreen_heading' => esc_html__( 'Start typing and press enter to search', 'olympuswp' ),
			'search_source' => 'any',
			'add_cart_icon' => false,
			'cart_count' => true,
			'cart_total' => true,
			'add_sticky' => false,
			'add_sticky_shadow' => false,
			'sticky_style' => 'classic',
			'sticky_logo' => '',
			'sticky_retina_logo' => '',
			'sticky_logo_width' => array(
				'desktop' => '',
				'tablet'  => '',
				'mobile'  => '',
			),
			'sticky_logo_width_unit' => 'px',
			'sticky_breakpoint' => '1024',
			'header_padding' => array(
				'desktop' => array(
					'top' => '20',
					'right' => '20',
					'bottom' => '20',
					'left' => '20',
				),
				'tablet' => array(
					'top' => '20',
					'right' => '20',
					'bottom' => '20',
					'left' => '20',
				),
				'mobile' => array(
					'top' => '20',
					'right' => '20',
					'bottom' => '20',
					'left' => '20',
				),
				'desktop-unit' => 'px',
				'tablet-unit' => 'px',
				'mobile-unit' => 'px',
			),
			'header_background' => '#ffffff',
			'menu_links_bg' => '',
			'menu_links_bg_hover' => '',
			'menu_links_color' => '',
			'menu_links_color_hover' => '',
			'sticky_background' => '',
			'sticky_links_color' => '',
			'sticky_links_color_hover' => '',
			'dropdown_width' => '200',
			'dropdown_width_unit' => 'px',
			'dropdown_border_top_height' => '1',
			'dropdown_links_bg' => '#ffffff',
			'dropdown_links_bg_hover' => '',
			'dropdown_links_color' => '',
			'dropdown_links_color_hover' => '',
			'dropdown_border_top_color' => '#222222',
			'search_dropdown_heading' => '#222222',
			'search_dropdown_bg' => '',
			'search_dropdown_input_bg' => '',
			'search_dropdown_input_color' => '#333333',
			'search_dropdown_input_border' => '',
			'search_dropdown_input_border_hover' => '',
			'search_dropdown_input_border_focus' => '',
			'search_fullscreen_bg' => '#333333',
			'search_fullscreen_title_color' => '#e2e2e2',
			'search_fullscreen_input_bg' => '',
			'search_fullscreen_input_color' => '#ffffff',
			'search_fullscreen_input_border' => 'rgba(255, 255, 255, 0.5)',
			'search_fullscreen_input_border_hover' => '',
			'search_fullscreen_input_border_focus' => '',
			'search_fullscreen_close_btn_color' => '#ffffff',
			'search_fullscreen_close_btn_color_hover' => '#ffffff',
			'search_slide_input_bg' => '',
			'search_slide_input_color' => '',
			'search_slide_input_border' => '',
			'search_slide_input_border_hover' => '',
			'search_slide_input_border_focus' => '',
			'search_slide_close_btn_color' => '',
			'search_slide_close_btn_color_hover' => '',
			'mobile_label' => esc_html__( 'Menu', 'olympuswp' ),
			'mobile_icon_size' => '20',
			'mobile_icon_size_unit' => 'px',
			'mobile_font_size' => '14',
			'mobile_font_size_unit' => 'px',
			'hide_title' => '',
			'add_breadcrumbs' => '',
			'breadcrumbs_source' => 'default',
			'page_header_padding' => array(
				'desktop' => array(
					'top' => '34',
					'right' => '',
					'bottom' => '34',
					'left' => '',
				),
				'tablet' => array(
					'top' => '',
					'right' => '',
					'bottom' => '',
					'left' => '',
				),
				'mobile' => array(
					'top' => '',
					'right' => '',
					'bottom' => '',
					'left' => '',
				),
				'desktop-unit' => 'px',
				'tablet-unit' => 'px',
				'mobile-unit' => 'px',
			),
			'page_header_background' => '#f5f5f5',
			'page_header_title_color' => '',
			'page_header_breadcrumbs_text_color' => '',
			'page_header_breadcrumbs_separator_color' => '',
			'page_header_breadcrumbs_links' => '',
			'page_header_breadcrumbs_links_hover' => '',
			'container_width' => '1290',
			'container_width_unit' => 'px',
			'general_layout' => 'right-sidebar',
			'blog_layout' => 'right-sidebar',
			'single_post_layout' => 'right-sidebar',
			'footer_columns' => '4',
			'global_color' => '#e5bf63',
			'global_color_hover' => '#e8c573',
			'background_color' => '#ffffff',
			'headings_color' => '#333333',
			'text_color' => '#777777',
			'link_color' => '#e5bf63',
			'link_color_hover' => '#333333',
			'link_color_active' => '',
			'link_color_visited' => '',
			'post_title_color' => '#333333',
			'post_title_color_hover' => '#e5bf63',
			'button_background_color' => '#e5bf63',
			'button_background_color_hover' => '#e8c573',
			'button_color' => '#ffffff',
			'button_color_hover' => '#ffffff',
			'archive_structure' => array(
				'image',
				'title-meta',
			),
			'archive_meta' => array(
				'author',
				'date',
				'cat',
				'comments',
			),
			'single_post_structure' => array(
				'image',
				'title-meta',
			),
			'single_meta' => array(
				'author',
				'date',
				'cat',
				'comments',
			),
			'footer_background' => '#f9f9f9',
			'footer_titles_color' => '#333333',
			'footer_text_color' => '#777777',
			'footer_links' => '',
			'footer_links_hover' => '',
			'footer_padding' => array(
				'desktop' => array(
					'top' => '40',
					'right' => '',
					'bottom' => '40',
					'left' => '',
				),
				'tablet' => array(
					'top' => '',
					'right' => '',
					'bottom' => '',
					'left' => '',
				),
				'mobile' => array(
					'top' => '',
					'right' => '',
					'bottom' => '',
					'left' => '',
				),
				'desktop-unit' => 'px',
				'tablet-unit' => 'px',
				'mobile-unit' => 'px',
			),
			'copyright' => '[copyright] Copyright [current_year] [site_title] - [theme]',
			'copyright_align' => array(
				'desktop' => 'center',
				'tablet'  => 'center',
				'mobile'  => 'center',
			),
			'copyright_background' => '#ececec',
			'copyright_text_color' => '#777777',
			'copyright_links' => '',
			'copyright_links_hover' => '',
			'copyright_font_size' => array(
				'desktop' => '14',
				'tablet'  => '',
				'mobile'  => '',
			),
			'copyright_font_size_unit' => 'px',
			'copyright_padding' => array(
				'desktop' => array(
					'top' => '10',
					'right' => '',
					'bottom' => '10',
					'left' => '',
				),
				'tablet' => array(
					'top' => '',
					'right' => '',
					'bottom' => '',
					'left' => '',
				),
				'mobile' => array(
					'top' => '',
					'right' => '',
					'bottom' => '',
					'left' => '',
				),
				'desktop-unit' => 'px',
				'tablet-unit' => 'px',
				'mobile-unit' => 'px',
			),
			'load_css_file' => false,
			'load_fonts_locally' => false,
			'preload_local_fonts' => false,
		);

		// LearnDash
		if ( defined( 'LEARNDASH_VERSION' ) ) {
			$ld_pt = array(
				'sfwd_quiz',
				'sfwd_certificates',
				'sfwd_lessons',
				'sfwd_topic',
				'sfwd_transactions',
				'sfwd_essays',
				'sfwd_assignment',
				'sfwd_courses',
				'ld_exam',
			);
			foreach ( $ld_pt as $name ) {
				$defaults[ $name . '_layout' ] = 'no-sidebar';
			}
		}

		// LifterLMS
		if ( class_exists( 'LifterLMS' ) ) {
			$llms_pt = array(
				'course',
				'lesson',
				'llms_quiz',
				'llms_membership',
				'llms_certificate',
				'llms_my_certificate',
			);
			foreach ( $llms_pt as $name ) {
				$defaults[ $name . '_layout' ] = 'no-sidebar';
			}
		}

		// If CPT
		$all_post_types = olympus_get_post_types_objects();
		foreach ( $all_post_types as $post_type_item ) {
			$post_type_name = $post_type_item->name;
			$ignore_type = olympus_get_post_types_to_ignore();

			if ( ! in_array( $post_type_name, $ignore_type, true ) ) {
				$defaults[ $post_type_name . '_layout' ] = 'right-sidebar';
				$defaults[ 'single_' . $post_type_name . '_layout' ] = 'right-sidebar';
			}
		}

		return apply_filters( 'olympus_option_defaults', $defaults );
	}
}

if ( ! function_exists( 'olympus_get_default_fonts' ) ) {
	/**
	 * Set default options.
	 *
	 * @param bool $filter Whether to return the filtered values or original values.
	 * @return array Option defaults.
	 *
	 * @since 1.0.0
	 */
	function olympus_get_default_fonts( $filter = true ) {
		$defaults = array(
			'font_body' => 'inherit',
			'body_font_weight' => 'normal',
			'body_font_transform' => 'none',
			'body_font_size' => array(
				'desktop' => '14',
				'tablet'  => '',
				'mobile'  => '',
			),
			'body_font_size_unit' => 'px',
			'body_line_height' => '1.8',
			'body_line_height_unit' => '-',
			'font_menu' => 'inherit',
			'menu_weight' => 'normal',
			'menu_transform' => 'none',
			'menu_font_size' => array(
				'desktop' => '15',
				'tablet'  => '',
				'mobile'  => '',
			),
			'menu_font_size_unit' => 'px',
			'menu_line_height' => '60',
			'menu_line_height_unit' => 'px',
			'font_headings' => 'inherit',
			'headings_weight' => 'normal',
			'headings_transform' => 'none',
			'headings_font_size' => array(
				'desktop' => '',
				'tablet'  => '',
				'mobile'  => '',
			),
			'headings_font_size_unit' => 'px',
			'headings_line_height' => '',
			'headings_line_height_unit' => '-',
			'font_heading_1' => 'inherit',
			'heading_1_weight' => 'normal',
			'heading_1_transform' => 'none',
			'heading_1_font_size' => array(
				'desktop' => '35',
				'tablet'  => '',
				'mobile'  => '24',
			),
			'heading_1_font_size_unit' => 'px',
			'heading_1_line_height' => '1.2',
			'heading_1_line_height_unit' => '-',
			'font_heading_2' => 'inherit',
			'heading_2_weight' => 'normal',
			'heading_2_transform' => 'none',
			'heading_2_font_size' => array(
				'desktop' => '28',
				'tablet'  => '',
				'mobile'  => '20',
			),
			'heading_2_font_size_unit' => 'px',
			'heading_2_line_height' => '1.2',
			'heading_2_line_height_unit' => '-',
			'font_heading_3' => 'inherit',
			'heading_3_weight' => 'normal',
			'heading_3_transform' => 'none',
			'heading_3_font_size' => '24',
			'heading_3_font_size_unit' => 'px',
			'heading_3_line_height' => '1.2',
			'heading_3_line_height_unit' => '-',
			'font_heading_4' => 'inherit',
			'heading_4_weight' => 'normal',
			'heading_4_transform' => 'none',
			'heading_4_font_size' => '20',
			'heading_4_font_size_unit' => 'px',
			'heading_4_line_height' => '',
			'heading_4_line_height_unit' => '-',
			'font_heading_5' => 'inherit',
			'heading_5_weight' => 'normal',
			'heading_5_transform' => 'none',
			'heading_5_font_size' => '18',
			'heading_5_font_size_unit' => 'px',
			'heading_5_line_height' => '',
			'heading_5_line_height_unit' => '-',
			'font_heading_6' => 'inherit',
			'heading_6_weight' => 'normal',
			'heading_6_transform' => 'none',
			'heading_6_font_size' => '15',
			'heading_6_font_size_unit' => 'px',
			'heading_6_line_height' => '',
			'heading_6_line_height_unit' => '-',
		);

		if ( $filter ) {
			return apply_filters( 'olympus_font_option_defaults', $defaults );
		}

		return $defaults;
	}
}

if ( ! function_exists( 'olympus_get_option' ) ) {
	/**
	 * A wrapper function to get our options.
	 *
	 * @param string $option The option name to look up.
	 * @return string The option value.
	 *
	 * @since 1.0.0
	 */
	function olympus_get_option( $option ) {
		$defaults = olympus_get_defaults();

		if ( ! isset( $defaults[ $option ] ) ) {
			return;
		}

		$options = wp_parse_args(
			get_option( 'olympus_settings', array() ),
			$defaults
		);

		return $options[ $option ];
	}
}

if ( ! function_exists( 'olympus_update_option' ) ) {
	/**
	 * Update Theme options.
	 *
	 * @param  string $option option key.
	 * @param  Mixed  $value  option value.
	 * @return void
	 */
	function olympus_update_option( $option, $value ) {
		do_action( "olympus_before_update_option_{$option}", $value, $option );

		// Get all customizer options.
		$options = get_option( 'olympus_settings' );

		// Update value in options array.
		$options[ $option ] = $value;

		update_option( 'olympus_settings', $options );

		do_action( "olympus_after_update_option_{$option}", $value, $option );
	}
}

if ( ! function_exists( 'olympus_delete_option' ) ) {
	/**
	 * Update Theme options.
	 *
	 * @param  string $option option key.
	 * @return void
	 */
	function olympus_delete_option( $option ) {
		do_action( "olympus_before_delete_option_{$option}", $option );

		// Get all customizer options.
		$options = get_option( 'olympus_settings' );

		// Update value in options array.
		unset( $options[ $option ] );

		update_option( 'olympus_settings', $options );

		do_action( "olympus_after_delete_option_{$option}", $option );
	}
}

if ( ! function_exists( 'olympus_get_layout' ) ) {
	/**
	 * Get the layout for the current page.
	 *
	 * @return string The sidebar layout location.
	 *
	 * @since 1.0.0
	 */
	function olympus_get_layout() {
		$layout = olympus_get_option( 'general_layout' );

		if ( is_home()
			|| is_archive()
			|| is_search()
			|| is_tax() ) {
			$layout = olympus_get_option( 'blog_layout' );
		}
		
		if ( is_404()
			|| is_singular( 'elementor_library' ) ) {
			$layout = 'no-sidebar';
		}
		
		if ( is_single() ) {
			$layout = olympus_get_option( 'single_post_layout' );
		}

		// LearnDash
		if ( defined( 'LEARNDASH_VERSION' ) ) {
			$ld_pt = array(
				'quiz',
				'certificates',
				'lessons',
				'topic',
				'transactions',
				'essays',
				'assignment',
				'courses',
			);
			foreach ( $ld_pt as $name ) {
				if ( is_singular( 'sfwd-' . $name ) ) {
					$layout = olympus_get_option( 'sfwd_' . $name . '_layout' );
				}
			}
			if ( is_singular( 'ld-exam' ) ) {
				$layout = olympus_get_option( 'ld_exam_layout' );
			}
		}

		// LifterLMS
		if ( class_exists( 'LifterLMS' ) ) {
			$llms_pt = array(
				'course',
				'lesson',
				'llms_quiz',
				'llms_membership',
				'llms_certificate',
				'llms_my_certificate',
			);
			foreach ( $llms_pt as $name ) {
				if ( is_singular( $name ) ) {
					$layout = olympus_get_option( $name . '_layout' );
				}
			}
		}
		
		// If Custom Post Type
		$all_post_types = olympus_get_post_types_objects();
		foreach ( $all_post_types as $post_type_item ) {
			$post_type_name = $post_type_item->name;
			$ignore_type = olympus_get_post_types_to_ignore();

			if ( ! in_array( $post_type_name, $ignore_type, true ) ) {
				if ( is_archive( $post_type_name )
					|| is_tax( $post_type_name ) ) {
					$layout = olympus_get_option( $post_type_name . '_layout' );
				}

				if ( is_singular( $post_type_name ) ) {
					$layout = olympus_get_option( 'single_' . $post_type_name . '_layout' );
				}
			}
		}
		
		if ( is_singular() ) {
			$layout_meta = get_post_meta( get_the_ID(), 'olympus-layout-meta', true );

			if ( $layout_meta ) {
				$layout = $layout_meta;
			}
		}

		return apply_filters( 'olympus_sidebar_layout', $layout );
	}
}

if ( ! function_exists( 'olympus_display_sidebar' ) ) {
	/**
	 * Display sidebar.
	 *
	 * @since 1.0.0
	 */
	function olympus_display_sidebar() {
		// Return if full width or full screen.
		if ( in_array( olympus_get_layout(), array( 'full-width', 'no-sidebar' ) ) ) {
			return;
		}

		// Add the default sidebar.
		get_sidebar();
	}
	add_action( 'olympus_sidebar', 'olympus_display_sidebar' );
}

if ( ! function_exists( 'olympus_post_thumbnail' ) ) {
	/**
	 * Displays an optional post thumbnail.
	 *
	 * Wraps the post thumbnail in an anchor element on index views, or a div
	 * element when on single views.
	 *
	 * @since 1.0.0
	 */
	function olympus_post_thumbnail() {
		if ( post_password_required() || is_attachment() || ! has_post_thumbnail() ) {
			return;
		}

		$attrs = array(
			'itemprop' => 'image'
		);
		
		echo apply_filters( // phpcs:ignore
			'olympus_featured_image_output',
			sprintf(
				'<div class="post-thumbnail">
					<a href="%1$s">
						%2$s
					</a>
				</div>',
				esc_url( get_permalink() ),
				get_the_post_thumbnail(
					get_the_ID(),
					apply_filters( 'olympus_blog_default_size', 'full' ),
					$attrs
				),
			)
		);
	}
}

if ( ! function_exists( 'olympus_get_post_types' ) ) {
	/**
	 * Get all post types.
	 *
	 * @since 1.1.0
	 */
	function olympus_get_post_types( $args = [] ) {
		$post_type_args = [
			'show_in_nav_menus' => true,
		];

		if ( ! empty( $args['post_type'] ) ) {
			$post_type_args['name'] = $args['post_type'];
		}

		$_post_types = get_post_types( $post_type_args, 'objects' );

		$post_types  = [];
		$post_types['any']  = esc_html__( 'Any', 'olympuswp' );

		foreach ( $_post_types as $post_type => $object ) {
			$post_types[ $post_type ] = $object->label;
		}

		return $post_types;
	}
}

/**
 * Get our CSS method.
 *
 * @since 1.1.1
 */
function olympus_get_css_method() {
	$mode = olympus_get_option( 'load_css_file' );

	if ( ( function_exists( 'is_customize_preview' ) && is_customize_preview() )
		|| is_preview()
		|| ( function_exists( 'is_amp_endpoint' ) && is_amp_endpoint() ) ) {
		return false;
	}

	if ( ! defined( 'OLY_VERSION' ) ) {
		return false;
	}

	return $mode;
}

/**
 * Get all public post types.
 *
 * @return array of post types.
 */
function olympus_get_post_types_objects() {
	$args = array(
		'public' => true,
		'_builtin' => false,
	);
	$output = 'objects'; // names or objects, note names is the default.
	$operator = 'and';
	$post_types = get_post_types( $args, $output, $operator );
	$post_types_objects = apply_filters( 'olympus_public_post_type_objects', $post_types );
	return $post_types_objects;
}

/**
 * Get array of post types we want to exclude from use in customizer custom post type settings.
 *
 * @return array of post types.
 */
function olympus_get_post_types_to_ignore() {
	$ignore_post_types = array(
		'post',
		'page',
		'product',
		'elementor_library',
		'shop_order',
		'jet-menu',
		'jet-popup',
		'jet-smart-filters',
		'jet-theme-core',
		'jet-woo-builder',
		'jet-engine',
		'course',
		'lesson',
		'llms_quiz',
		'llms_membership',
		'llms_certificate',
		'llms_my_certificate',
		'sfwd-quiz',
		'sfwd-certificates',
		'sfwd-lessons',
		'sfwd-topic',
		'sfwd-transactions',
		'sfwd-essays',
		'sfwd-assignment',
		'sfwd-courses',
		'ld-exam',
		'tutor_quiz',
		'tutor_assignments',
		'courses',
		'groups',
		'forum',
		'topic',
		'reply',
		'tribe_events',
	);
	$ignore_post_types = apply_filters( 'olympus_customizer_post_type_ignore_array', $ignore_post_types );

	return $ignore_post_types;
}

if ( ! function_exists( 'olympus_llms_sidebar_function' ) ) {
	/**
	 * Display LifterLMS Course and Lesson sidebars
	 * on courses and lessons in place of the sidebar returned by this function.
	 */
	function olympus_llms_sidebar_function( $id ) {
		$id = 'olympus-sidebar';
		return $id;
	}
	add_filter( 'llms_get_theme_default_sidebar', 'olympus_llms_sidebar_function' );
}

if ( ! function_exists( 'olympus_get_premium_url' ) ) {
	/**
	 * Create a URL to the pro version.
	 * Allows the use of a referral ID and campaign.
	 *
	 * @since 1.1.3
	 *
	 * @param string $url URL to premium page.
	 * @param bool   $trailing_slash Whether we want to include a trailing slash.
	 * @return string The URL to wpolympus.com.
	 */
	function olympus_get_premium_url( $url = 'https://wpolympus.com/pro', $trailing_slash = true ) {
		if ( $trailing_slash ) {
			$url = trailingslashit( $url );
		}

		$args = apply_filters(
			'olympus_premium_url_args',
			array(
				'ref' => null,
				'campaign' => null,
			)
		);

		if ( isset( $args['ref'] ) ) {
			$url = add_query_arg( 'ref', absint( $args['ref'] ), $url );
		}

		if ( isset( $args['campaign'] ) ) {
			$url = add_query_arg( 'campaign', sanitize_text_field( $args['campaign'] ), $url );
		}

		return esc_url( $url );
	}
}
